Class: Aws::ApplicationSignals::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ApplicationSignals::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-applicationsignals/client.rb
Overview
An API client for ApplicationSignals. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ApplicationSignals::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_delete_instrumentation_configurations(params = {}) ⇒ Types::BatchDeleteInstrumentationConfigurationsResponse
Deletes multiple instrumentation configurations in a single request.
-
#batch_get_service_level_objective_budget_report(params = {}) ⇒ Types::BatchGetServiceLevelObjectiveBudgetReportOutput
Use this operation to retrieve one or more *service level objective (SLO) budget reports*.
-
#batch_update_exclusion_windows(params = {}) ⇒ Types::BatchUpdateExclusionWindowsOutput
Add or remove time window exclusions for one or more Service Level Objectives (SLOs).
-
#create_instrumentation_configuration(params = {}) ⇒ Types::CreateInstrumentationConfigurationResponse
Creates a dynamic instrumentation configuration for a specific code or endpoint location within a service and environment.
-
#create_service_level_objective(params = {}) ⇒ Types::CreateServiceLevelObjectiveOutput
Creates a service level objective (SLO), which can help you ensure that your critical business operations are meeting customer expectations.
-
#delete_grouping_configuration(params = {}) ⇒ Struct
Deletes the grouping configuration for this account.
-
#delete_instrumentation_configuration(params = {}) ⇒ Types::DeleteInstrumentationConfigurationResponse
Deletes the specified instrumentation configuration.
-
#delete_service_level_objective(params = {}) ⇒ Struct
Deletes the specified service level objective.
-
#get_instrumentation_configuration(params = {}) ⇒ Types::GetInstrumentationConfigurationResponse
Returns the details of a single instrumentation configuration identified by service, environment, signal type, and location.
-
#get_instrumentation_configuration_status(params = {}) ⇒ Types::GetInstrumentationConfigurationStatusResponse
Retrieves the status history for a single instrumentation configuration during a specified time range.
-
#get_service(params = {}) ⇒ Types::GetServiceOutput
Returns information about a service discovered by Application Signals.
-
#get_service_level_objective(params = {}) ⇒ Types::GetServiceLevelObjectiveOutput
Returns information about one SLO created in the account.
-
#list_audit_findings(params = {}) ⇒ Types::ListAuditFindingsOutput
Returns a list of audit findings that provide automated analysis of service behavior and root cause analysis.
-
#list_entity_events(params = {}) ⇒ Types::ListEntityEventsOutput
Returns a list of change events for a specific entity, such as deployments, configuration changes, or other state-changing activities.
-
#list_grouping_attribute_definitions(params = {}) ⇒ Types::ListGroupingAttributeDefinitionsOutput
Returns the current grouping configuration for this account, including all custom grouping attribute definitions that have been configured.
-
#list_instrumentation_configurations(params = {}) ⇒ Types::InstrumentationConfigurationsPage
Returns all active instrumentation configurations for a service and environment.
-
#list_service_dependencies(params = {}) ⇒ Types::ListServiceDependenciesOutput
Returns a list of service dependencies of the service that you specify.
-
#list_service_dependents(params = {}) ⇒ Types::ListServiceDependentsOutput
Returns the list of dependents that invoked the specified service during the provided time range.
-
#list_service_level_objective_exclusion_windows(params = {}) ⇒ Types::ListServiceLevelObjectiveExclusionWindowsOutput
Retrieves all exclusion windows configured for a specific SLO.
-
#list_service_level_objectives(params = {}) ⇒ Types::ListServiceLevelObjectivesOutput
Returns a list of SLOs created in this account.
-
#list_service_operations(params = {}) ⇒ Types::ListServiceOperationsOutput
Returns a list of the operations of this service that have been discovered by Application Signals.
-
#list_service_states(params = {}) ⇒ Types::ListServiceStatesOutput
Returns information about the last deployment and other change states of services.
-
#list_services(params = {}) ⇒ Types::ListServicesOutput
Returns a list of services that have been discovered by Application Signals.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with a CloudWatch resource.
-
#put_grouping_configuration(params = {}) ⇒ Types::PutGroupingConfigurationOutput
Creates or updates the grouping configuration for this account.
-
#report_instrumentation_configuration_status(params = {}) ⇒ Types::ReportInstrumentationConfigurationStatusResponse
Reports the status of one or more instrumentation configurations from SDK instances.
-
#start_discovery(params = {}) ⇒ Struct
Enables this Amazon Web Services account to be able to use CloudWatch Application Signals by creating the AWSServiceRoleForCloudWatchApplicationSignals service-linked role.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch resource, such as a service level objective.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_service_level_objective(params = {}) ⇒ Types::UpdateServiceLevelObjectiveOutput
Updates an existing service level objective (SLO).
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3756 3757 3758 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3756 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3759 3760 3761 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3759 def errors_module Errors end |
Instance Method Details
#batch_delete_instrumentation_configurations(params = {}) ⇒ Types::BatchDeleteInstrumentationConfigurationsResponse
Deletes multiple instrumentation configurations in a single request. Supports two mutually exclusive selection methods:
-
By scope: Delete all configurations matching a Service + Environment + InstrumentationType
-
By ARN list: Delete specific configurations by providing a list of resource ARNs
526 527 528 529 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 526 def batch_delete_instrumentation_configurations(params = {}, = {}) req = build_request(:batch_delete_instrumentation_configurations, params) req.send_request() end |
#batch_get_service_level_objective_budget_report(params = {}) ⇒ Types::BatchGetServiceLevelObjectiveBudgetReportOutput
Use this operation to retrieve one or more *service level objective (SLO) budget reports*.
An *error budget* is the amount of time or requests in an unhealthy state that your service can accumulate during an interval before your overall SLO budget health is breached and the SLO is considered to be unmet. For example, an SLO with a threshold of 99.95% and a monthly interval translates to an error budget of 21.9 minutes of downtime in a 30-day month.
Budget reports include a health indicator, the attainment value, and remaining budget.
For more information about SLO error budgets, see [ SLO concepts].
695 696 697 698 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 695 def batch_get_service_level_objective_budget_report(params = {}, = {}) req = build_request(:batch_get_service_level_objective_budget_report, params) req.send_request() end |
#batch_update_exclusion_windows(params = {}) ⇒ Types::BatchUpdateExclusionWindowsOutput
Add or remove time window exclusions for one or more Service Level Objectives (SLOs).
764 765 766 767 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 764 def batch_update_exclusion_windows(params = {}, = {}) req = build_request(:batch_update_exclusion_windows, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3729 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ApplicationSignals') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-applicationsignals' context[:gem_version] = '1.45.0' Seahorse::Client::Request.new(handlers, context) end |
#create_instrumentation_configuration(params = {}) ⇒ Types::CreateInstrumentationConfigurationResponse
Creates a dynamic instrumentation configuration for a specific code or endpoint location within a service and environment. Configurations are immutable after creation.
For ‘BREAKPOINT` type configurations, they expire after 24 hours unless a shorter expiration is provided. For `PROBE` type configurations, they persist until explicitly deleted; an expiration cannot be set for `PROBE` configurations.
If a configuration already exists for the same service, environment, signal type, and location, this operation returns a conflict instead of overwriting it. Use attribute filters and capture settings to control where the instrumentation runs and which data is collected.
929 930 931 932 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 929 def create_instrumentation_configuration(params = {}, = {}) req = build_request(:create_instrumentation_configuration, params) req.send_request() end |
#create_service_level_objective(params = {}) ⇒ Types::CreateServiceLevelObjectiveOutput
Creates a service level objective (SLO), which can help you ensure that your critical business operations are meeting customer expectations. Use SLOs to set and track specific target levels for the reliability and availability of your applications and services. SLOs use service level indicators (SLIs) to calculate whether the application is performing at the level that you want.
Create an SLO to set a target for a service or operation’s availability or latency. CloudWatch measures this target frequently you can find whether it has been breached.
The target performance quality that is defined for an SLO is the *attainment goal*.
You can set SLO targets for your applications that are discovered by Application Signals, using critical metrics such as latency and availability. You can also set SLOs against any CloudWatch metric or math expression that produces a time series.
<note markdown=“1”> You can’t create an SLO for a service operation that was discovered by Application Signals until after that operation has reported standard metrics to Application Signals.
</note>
When you create an SLO, you specify whether it is a *period-based SLO* or a *request-based SLO*. Each type of SLO has a different way of evaluating your application’s performance against its attainment goal.
-
A *period-based SLO* uses defined periods of time within a specified total time interval. For each period of time, Application Signals determines whether the application met its goal. The attainment rate is calculated as the ‘number of good periods/number of total periods`.
For example, for a period-based SLO, meeting an attainment goal of 99.9% means that within your interval, your application must meet its performance goal during at least 99.9% of the time periods.
-
A *request-based SLO* doesn’t use pre-defined periods of time. Instead, the SLO measures ‘number of good requests/number of total requests` during the interval. At any time, you can find the ratio of good requests to total requests for the interval up to the time stamp that you specify, and measure that ratio against the goal set in your SLO.
After you have created an SLO, you can retrieve error budget reports for it. An *error budget* is the amount of time or amount of requests that your application can be non-compliant with the SLO’s goal, and still have your application meet the goal.
-
For a period-based SLO, the error budget starts at a number defined by the highest number of periods that can fail to meet the threshold, while still meeting the overall goal. The *remaining error budget* decreases with every failed period that is recorded. The error budget within one interval can never increase.
For example, an SLO with a threshold that 99.95% of requests must be completed under 2000ms every month translates to an error budget of 21.9 minutes of downtime per month.
-
For a request-based SLO, the remaining error budget is dynamic and can increase or decrease, depending on the ratio of good requests to total requests.
For more information about SLOs, see [ Service level objectives (SLOs)].
When you perform a ‘CreateServiceLevelObjective` operation, Application Signals creates the AWSServiceRoleForCloudWatchApplicationSignals service-linked role, if it doesn’t already exist in your account. This service- linked role has the following permissions:
-
‘xray:GetServiceGraph`
-
‘logs:StartQuery`
-
‘logs:GetQueryResults`
-
‘cloudwatch:GetMetricData`
-
‘cloudwatch:ListMetrics`
-
‘tag:GetResources`
-
‘autoscaling:DescribeAutoScalingGroups`
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-ServiceLevelObjectives.html
1414 1415 1416 1417 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1414 def create_service_level_objective(params = {}, = {}) req = build_request(:create_service_level_objective, params) req.send_request() end |
#delete_grouping_configuration(params = {}) ⇒ Struct
Deletes the grouping configuration for this account. This removes all custom grouping attribute definitions that were previously configured.
1428 1429 1430 1431 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1428 def delete_grouping_configuration(params = {}, = {}) req = build_request(:delete_grouping_configuration, params) req.send_request() end |
#delete_instrumentation_configuration(params = {}) ⇒ Types::DeleteInstrumentationConfigurationResponse
Deletes the specified instrumentation configuration. SDKs remove the instrumentation during their next sync after the configuration is deleted or expires.
1486 1487 1488 1489 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1486 def delete_instrumentation_configuration(params = {}, = {}) req = build_request(:delete_instrumentation_configuration, params) req.send_request() end |
#delete_service_level_objective(params = {}) ⇒ Struct
Deletes the specified service level objective.
1508 1509 1510 1511 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1508 def delete_service_level_objective(params = {}, = {}) req = build_request(:delete_service_level_objective, params) req.send_request() end |
#get_instrumentation_configuration(params = {}) ⇒ Types::GetInstrumentationConfigurationResponse
Returns the details of a single instrumentation configuration identified by service, environment, signal type, and location. Use this to audit or display configuration details.
1597 1598 1599 1600 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1597 def get_instrumentation_configuration(params = {}, = {}) req = build_request(:get_instrumentation_configuration, params) req.send_request() end |
#get_instrumentation_configuration_status(params = {}) ⇒ Types::GetInstrumentationConfigurationStatusResponse
Retrieves the status history for a single instrumentation configuration during a specified time range. The response lists when the configuration was ACTIVE, READY, ERROR, or DISABLED.
If no status or time window is provided, the operation defaults to ACTIVE events from the last hour.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1706 1707 1708 1709 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1706 def get_instrumentation_configuration_status(params = {}, = {}) req = build_request(:get_instrumentation_configuration_status, params) req.send_request() end |
#get_service(params = {}) ⇒ Types::GetServiceOutput
Returns information about a service discovered by Application Signals.
1801 1802 1803 1804 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1801 def get_service(params = {}, = {}) req = build_request(:get_service, params) req.send_request() end |
#get_service_level_objective(params = {}) ⇒ Types::GetServiceLevelObjectiveOutput
Returns information about one SLO created in the account.
1945 1946 1947 1948 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 1945 def get_service_level_objective(params = {}, = {}) req = build_request(:get_service_level_objective, params) req.send_request() end |
#list_audit_findings(params = {}) ⇒ Types::ListAuditFindingsOutput
Returns a list of audit findings that provide automated analysis of service behavior and root cause analysis. These findings help identify the most significant observations about your services, including performance issues, anomalies, and potential problems. The findings are generated using heuristic algorithms based on established troubleshooting patterns.
2133 2134 2135 2136 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2133 def list_audit_findings(params = {}, = {}) req = build_request(:list_audit_findings, params) req.send_request() end |
#list_entity_events(params = {}) ⇒ Types::ListEntityEventsOutput
Returns a list of change events for a specific entity, such as deployments, configuration changes, or other state-changing activities. This operation helps track the history of changes that may have affected service performance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2238 2239 2240 2241 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2238 def list_entity_events(params = {}, = {}) req = build_request(:list_entity_events, params) req.send_request() end |
#list_grouping_attribute_definitions(params = {}) ⇒ Types::ListGroupingAttributeDefinitionsOutput
Returns the current grouping configuration for this account, including all custom grouping attribute definitions that have been configured. These definitions determine how services are logically grouped based on telemetry attributes, Amazon Web Services tags, or predefined mappings.
2291 2292 2293 2294 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2291 def list_grouping_attribute_definitions(params = {}, = {}) req = build_request(:list_grouping_attribute_definitions, params) req.send_request() end |
#list_instrumentation_configurations(params = {}) ⇒ Types::InstrumentationConfigurationsPage
Returns all active instrumentation configurations for a service and environment. SDKs use this operation to sync configurations and apply client-side filters locally.
Include the previous ‘SyncedAt` value to perform incremental syncs. When no changes are detected, the response sets `Changed` to `false` and omits configuration details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2395 2396 2397 2398 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2395 def list_instrumentation_configurations(params = {}, = {}) req = build_request(:list_instrumentation_configurations, params) req.send_request() end |
#list_service_dependencies(params = {}) ⇒ Types::ListServiceDependenciesOutput
Returns a list of service dependencies of the service that you specify. A dependency is an infrastructure component that an operation of this service connects with. Dependencies can include Amazon Web Services services, Amazon Web Services resources, and third-party services.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2496 2497 2498 2499 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2496 def list_service_dependencies(params = {}, = {}) req = build_request(:list_service_dependencies, params) req.send_request() end |
#list_service_dependents(params = {}) ⇒ Types::ListServiceDependentsOutput
Returns the list of dependents that invoked the specified service during the provided time range. Dependents include other services, CloudWatch Synthetics canaries, and clients that are instrumented with CloudWatch RUM app monitors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2596 2597 2598 2599 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2596 def list_service_dependents(params = {}, = {}) req = build_request(:list_service_dependents, params) req.send_request() end |
#list_service_level_objective_exclusion_windows(params = {}) ⇒ Types::ListServiceLevelObjectiveExclusionWindowsOutput
Retrieves all exclusion windows configured for a specific SLO.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2643 2644 2645 2646 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2643 def list_service_level_objective_exclusion_windows(params = {}, = {}) req = build_request(:list_service_level_objective_exclusion_windows, params) req.send_request() end |
#list_service_level_objectives(params = {}) ⇒ Types::ListServiceLevelObjectivesOutput
Returns a list of SLOs created in this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2783 2784 2785 2786 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2783 def list_service_level_objectives(params = {}, = {}) req = build_request(:list_service_level_objectives, params) req.send_request() end |
#list_service_operations(params = {}) ⇒ Types::ListServiceOperationsOutput
Returns a list of the operations of this service that have been discovered by Application Signals. Only the operations that were invoked during the specified time range are returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2879 2880 2881 2882 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2879 def list_service_operations(params = {}, = {}) req = build_request(:list_service_operations, params) req.send_request() end |
#list_service_states(params = {}) ⇒ Types::ListServiceStatesOutput
Returns information about the last deployment and other change states of services. This API provides visibility into recent changes that may have affected service performance, helping with troubleshooting and change correlation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2973 2974 2975 2976 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 2973 def list_service_states(params = {}, = {}) req = build_request(:list_service_states, params) req.send_request() end |
#list_services(params = {}) ⇒ Types::ListServicesOutput
Returns a list of services that have been discovered by Application Signals. A service represents a minimum logical and transactional unit that completes a business function. Services are discovered through Application Signals instrumentation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3061 3062 3063 3064 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3061 def list_services(params = {}, = {}) req = build_request(:list_services, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with a CloudWatch resource. Tags can be assigned to service level objectives.
3103 3104 3105 3106 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3103 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_grouping_configuration(params = {}) ⇒ Types::PutGroupingConfigurationOutput
Creates or updates the grouping configuration for this account. This operation allows you to define custom grouping attributes that determine how services are logically grouped based on telemetry attributes, Amazon Web Services tags, or predefined mappings. These grouping attributes can then be used to organize and filter services in the Application Signals console and APIs.
3149 3150 3151 3152 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3149 def put_grouping_configuration(params = {}, = {}) req = build_request(:put_grouping_configuration, params) req.send_request() end |
#report_instrumentation_configuration_status(params = {}) ⇒ Types::ReportInstrumentationConfigurationStatusResponse
Reports the status of one or more instrumentation configurations from SDK instances. Use this to record when configurations become ready, hit errors, become active, or are disabled by limits.
Report ‘READY`, `ERROR`, and `DISABLED` when the status changes. Report `ACTIVE` periodically (for example, every minute) while instrumentation is running.
3212 3213 3214 3215 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3212 def report_instrumentation_configuration_status(params = {}, = {}) req = build_request(:report_instrumentation_configuration_status, params) req.send_request() end |
#start_discovery(params = {}) ⇒ Struct
Enables this Amazon Web Services account to be able to use CloudWatch Application Signals by creating the AWSServiceRoleForCloudWatchApplicationSignals service-linked role. This service- linked role has the following permissions:
-
‘xray:GetServiceGraph`
-
‘logs:StartQuery`
-
‘logs:GetQueryResults`
-
‘cloudwatch:GetMetricData`
-
‘cloudwatch:ListMetrics`
-
‘tag:GetResources`
-
‘autoscaling:DescribeAutoScalingGroups`
A service-linked CloudTrail event channel is created to process CloudTrail events and return change event information. This includes last deployment time, userName, eventName, and other event metadata.
After completing this step, you still need to instrument your Java and Python applications to send data to Application Signals. For more information, see [ Enabling Application Signals].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Application-Signals-Enable.html
3254 3255 3256 3257 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3254 def start_discovery(params = {}, = {}) req = build_request(:start_discovery, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch resource, such as a service level objective.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
Tags don’t have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the ‘TagResource` action with an alarm that already has tags. If you specify a new tag key for the alarm, this tag is appended to the list of tags associated with the alarm. If you specify a tag key that is already associated with the alarm, the new tag value that you specify replaces the previous value for that tag.
You can associate as many as 50 tags with a CloudWatch resource.
3312 3313 3314 3315 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3312 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
3349 3350 3351 3352 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3349 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_service_level_objective(params = {}) ⇒ Types::UpdateServiceLevelObjectiveOutput
Updates an existing service level objective (SLO). If you omit parameters, the previous values of those parameters are retained.
You cannot change from a period-based SLO to a request-based SLO, or change from a request-based SLO to a period-based SLO.
3720 3721 3722 3723 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3720 def update_service_level_objective(params = {}, = {}) req = build_request(:update_service_level_objective, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3749 3750 3751 |
# File 'lib/aws-sdk-applicationsignals/client.rb', line 3749 def waiter_names [] end |