Class: Aws::ApplicationSignals::Types::BatchDeleteDeletionTarget

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Note:

BatchDeleteDeletionTarget is a union - when making an API calls you must set exactly one of the members.

Union type for batch delete target selection. Exactly one of the two modes must be specified.

Direct Known Subclasses

ResourceArns, Scope, Unknown

Defined Under Namespace

Classes: ResourceArns, Scope, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnsTypes::BatchDeleteByResourceArns

Delete specific configurations by ARN list.



233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/aws-sdk-applicationsignals/types.rb', line 233

class BatchDeleteDeletionTarget < Struct.new(
  :scope,
  :resource_arns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Scope < BatchDeleteDeletionTarget; end
  class ResourceArns < BatchDeleteDeletionTarget; end
  class Unknown < BatchDeleteDeletionTarget; end
end

#scopeTypes::BatchDeleteScope

Delete all configurations matching the specified scope.



233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/aws-sdk-applicationsignals/types.rb', line 233

class BatchDeleteDeletionTarget < Struct.new(
  :scope,
  :resource_arns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Scope < BatchDeleteDeletionTarget; end
  class ResourceArns < BatchDeleteDeletionTarget; end
  class Unknown < BatchDeleteDeletionTarget; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



233
234
235
# File 'lib/aws-sdk-applicationsignals/types.rb', line 233

def unknown
  @unknown
end