Class: Aws::ApplicationSignals::Types::CaptureConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Note:

CaptureConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

CaptureConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CaptureConfiguration corresponding to the set member.

A union that defines what data to capture when the instrumentation point is hit. Specify ‘CodeCapture` for code-level capture settings.

Direct Known Subclasses

CodeCapture, Unknown

Defined Under Namespace

Classes: CodeCapture, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_captureTypes::CodeCaptureConfiguration

Capture settings for code-level instrumentation, including arguments, return values, stack traces, local variables, and safety limits.



566
567
568
569
570
571
572
573
574
575
# File 'lib/aws-sdk-applicationsignals/types.rb', line 566

class CaptureConfiguration < Struct.new(
  :code_capture,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CodeCapture < CaptureConfiguration; end
  class Unknown < CaptureConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



566
567
568
# File 'lib/aws-sdk-applicationsignals/types.rb', line 566

def unknown
  @unknown
end