Class: Aws::ApplicationSignals::Types::CaptureLimitsConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Guardrails that prevent instrumentation from impacting application performance by limiting how much data is captured.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_collection_depthInteger

The maximum nesting depth to traverse inside collections. Defaults to 3.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end

#max_collection_widthInteger

The maximum number of items to capture from any collection to prevent large payloads. Defaults to 10.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end

#max_fields_per_objectInteger

The maximum number of fields to capture for any object. Defaults to 10.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end

#max_hitsInteger

The maximum number of times the instrumentation point can be hit before it is automatically disabled. Defaults to 100.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end

#max_object_depthInteger

The maximum depth for nested object traversal when capturing structured data. Defaults to 3.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end

#max_stack_framesInteger

The maximum number of stack frames to capture in stack traces. Defaults to 2.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end

#max_stack_trace_sizeInteger

The maximum total size, in bytes, of a captured stack trace. Defaults to 1000.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end

#max_string_lengthInteger

The maximum length of captured string values in characters. Strings longer than this are truncated. Defaults to 128.

Returns:

  • (Integer)


622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622

class CaptureLimitsConfig < Struct.new(
  :max_hits,
  :max_string_length,
  :max_collection_width,
  :max_collection_depth,
  :max_stack_frames,
  :max_stack_trace_size,
  :max_object_depth,
  :max_fields_per_object)
  SENSITIVE = []
  include Aws::Structure
end