Class: Aws::ApplicationSignals::Types::CodeCaptureConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::CodeCaptureConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Defines what data to capture for code-level instrumentation, including arguments, return values, stack traces, local variables, and safety limits.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capture_arguments ⇒ Array<String>
The function arguments to capture.
-
#capture_limits ⇒ Types::CaptureLimitsConfig
Safety limits that bound what is captured, including hit counts, string length, collection depth, and stack trace size.
-
#capture_locals ⇒ Array<String>
The local variables to capture by name.
-
#capture_return ⇒ Boolean
Whether to capture the return value.
-
#capture_stack_trace ⇒ Boolean
Whether to capture a stack trace when the instrumentation point is hit.
Instance Attribute Details
#capture_arguments ⇒ Array<String>
The function arguments to capture. Omit to capture defaults, use an empty list to capture none, use ‘[“*”]` to capture all arguments, or specify argument names to capture selectively (up to 10 entries).
751 752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 751 class CodeCaptureConfiguration < Struct.new( :capture_arguments, :capture_return, :capture_stack_trace, :capture_locals, :capture_limits) SENSITIVE = [] include Aws::Structure end |
#capture_limits ⇒ Types::CaptureLimitsConfig
Safety limits that bound what is captured, including hit counts, string length, collection depth, and stack trace size.
751 752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 751 class CodeCaptureConfiguration < Struct.new( :capture_arguments, :capture_return, :capture_stack_trace, :capture_locals, :capture_limits) SENSITIVE = [] include Aws::Structure end |
#capture_locals ⇒ Array<String>
The local variables to capture by name. Omit or pass an empty list to capture none. You can specify up to 20 names.
751 752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 751 class CodeCaptureConfiguration < Struct.new( :capture_arguments, :capture_return, :capture_stack_trace, :capture_locals, :capture_limits) SENSITIVE = [] include Aws::Structure end |
#capture_return ⇒ Boolean
Whether to capture the return value. Defaults to false.
751 752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 751 class CodeCaptureConfiguration < Struct.new( :capture_arguments, :capture_return, :capture_stack_trace, :capture_locals, :capture_limits) SENSITIVE = [] include Aws::Structure end |
#capture_stack_trace ⇒ Boolean
Whether to capture a stack trace when the instrumentation point is hit. Defaults to true.
751 752 753 754 755 756 757 758 759 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 751 class CodeCaptureConfiguration < Struct.new( :capture_arguments, :capture_return, :capture_stack_trace, :capture_locals, :capture_limits) SENSITIVE = [] include Aws::Structure end |