Class: Aws::ApplicationSignals::Types::CodeLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Identifies a code location to instrument, including the programming language, code unit, class, method, file path, and optional line number.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#class_nameString

The class or type name that contains the method. This is required for Java and optional for Python module-level functions.

Returns:

  • (String)


798
799
800
801
802
803
804
805
806
807
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798

class CodeLocation < Struct.new(
  :language,
  :code_unit,
  :class_name,
  :method_name,
  :file_path,
  :line_number)
  SENSITIVE = []
  include Aws::Structure
end

#code_unitString

The package, module, or namespace that contains the target code, for example ‘com.amazon.payment` or `payment_service`.

Returns:

  • (String)


798
799
800
801
802
803
804
805
806
807
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798

class CodeLocation < Struct.new(
  :language,
  :code_unit,
  :class_name,
  :method_name,
  :file_path,
  :line_number)
  SENSITIVE = []
  include Aws::Structure
end

#file_pathString

The source file path relative to the project or source root, such as ‘src/payment/PaymentProcessor.java` or `src/payment/PaymentProcessor.py`.

Returns:

  • (String)


798
799
800
801
802
803
804
805
806
807
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798

class CodeLocation < Struct.new(
  :language,
  :code_unit,
  :class_name,
  :method_name,
  :file_path,
  :line_number)
  SENSITIVE = []
  include Aws::Structure
end

#languageString

The programming language for this instrumentation point, such as Java, Python, or JavaScript.

Returns:

  • (String)


798
799
800
801
802
803
804
805
806
807
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798

class CodeLocation < Struct.new(
  :language,
  :code_unit,
  :class_name,
  :method_name,
  :file_path,
  :line_number)
  SENSITIVE = []
  include Aws::Structure
end

#line_numberInteger

The line number to instrument. Provide this to disambiguate overloaded methods and to target a specific line when needed.

Returns:

  • (Integer)


798
799
800
801
802
803
804
805
806
807
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798

class CodeLocation < Struct.new(
  :language,
  :code_unit,
  :class_name,
  :method_name,
  :file_path,
  :line_number)
  SENSITIVE = []
  include Aws::Structure
end

#method_nameString

The method or function name to instrument, such as ‘validateCreditCard` or `__init__`.

Returns:

  • (String)


798
799
800
801
802
803
804
805
806
807
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798

class CodeLocation < Struct.new(
  :language,
  :code_unit,
  :class_name,
  :method_name,
  :file_path,
  :line_number)
  SENSITIVE = []
  include Aws::Structure
end