Class: Aws::ApplicationSignals::Types::CompositeSliComponent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Note:

CompositeSliComponent is a union - when making an API calls you must set exactly one of the members.

Note:

CompositeSliComponent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CompositeSliComponent corresponding to the set member.

Identifies a single operation to include in a composite SLI for a service-level SLO. Used as an element of the ‘Components` list in `CompositeSliConfig`.

Direct Known Subclasses

OperationName, Unknown

Defined Under Namespace

Classes: OperationName, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operation_nameString

The name of the operation to include in the composite SLI.

Returns:

  • (String)


823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-applicationsignals/types.rb', line 823

class CompositeSliComponent < Struct.new(
  :operation_name,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OperationName < CompositeSliComponent; end
  class Unknown < CompositeSliComponent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



823
824
825
# File 'lib/aws-sdk-applicationsignals/types.rb', line 823

def unknown
  @unknown
end