Class: Aws::ApplicationSignals::Types::CompositeSliConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

This structure contains the configuration for a composite service level indicator (SLI) that aggregates metrics across multiple operations of a service for service-level SLOs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#componentsArray<Types::CompositeSliComponent>

The list of operations included in this composite SLI. You must specify between 2 and 20 components. Each component is a ‘CompositeSliComponent` that identifies a single operation by its `OperationName`.

Returns:



520
521
522
523
524
525
# File 'lib/aws-sdk-applicationsignals/types.rb', line 520

class CompositeSliConfig < Struct.new(
  :selection_config,
  :components)
  SENSITIVE = []
  include Aws::Structure
end

#selection_configTypes::SelectionConfig

Specifies how operations are selected for this service-level SLO. Operations can be selected explicitly by listing them, by specifying a prefix to match operation names, or by providing a regular expression pattern.



520
521
522
523
524
525
# File 'lib/aws-sdk-applicationsignals/types.rb', line 520

class CompositeSliConfig < Struct.new(
  :selection_config,
  :components)
  SENSITIVE = []
  include Aws::Structure
end