Class: Aws::ApplicationSignals::Types::CreateInstrumentationConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_filtersArray<Hash<String,String>>

Client-side filters that target specific instances. Each object in the array is AND-matched on its keys, and multiple objects are OR-matched to decide where to apply the instrumentation.

Returns:

  • (Array<Hash<String,String>>)


928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#capture_configurationTypes::CaptureConfiguration

Specifies what to capture when the instrumentation point is hit. Specify ‘CodeCapture` for code-level capture settings.



928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional short description (up to 50 characters) that explains the purpose of this instrumentation.

Returns:

  • (String)


928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#environmentString

The environment that the service is running in, such as ‘eks:cluster-prod/namespace` or `ec2:production`.

Returns:

  • (String)


928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

For BREAKPOINT: optional, defaults to 24 hours, must be between 5 min and 24 hours. For PROBE: not supported. PROBE configurations are permanent and persist until explicitly deleted.

Returns:

  • (Time)


928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instrumentation_typeString

Type of instrumentation: BREAKPOINT (temporary) or PROBE (permanent)

Returns:

  • (String)


928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

The location where instrumentation should be applied. Specify a ‘CodeLocation` for code-level instrumentation.

Returns:



928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The name of the service to instrument. This should match the ‘service.name` resource attribute reported by the application.

Returns:

  • (String)


928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

The telemetry signal type to emit for this instrumentation. The supported value is ‘SNAPSHOT`.

Returns:

  • (String)


928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An optional list of key-value pairs to associate with the instrumentation configuration. Tags can help you organize and categorize your resources.

Returns:



928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928

class CreateInstrumentationConfigurationRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end