Class: Aws::ApplicationSignals::Types::CreateInstrumentationConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

ARN for the created instrumentation configuration

Returns:

  • (String)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#attribute_filtersArray<Hash<String,String>>

The attribute filters returned with the configuration so SDKs can perform client-side targeting.

Returns:

  • (Array<Hash<String,String>>)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#capture_configurationTypes::CaptureConfiguration

The capture settings that were stored for this instrumentation configuration.



1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The server-generated creation timestamp for this instrumentation configuration.

Returns:

  • (Time)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The optional description that was stored with the instrumentation configuration.

Returns:

  • (String)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#environmentString

The environment for the instrumentation configuration, echoed from the request.

Returns:

  • (String)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

The timestamp after which this configuration is no longer served to clients. Present only for ‘BREAKPOINT` configurations; `PROBE` configurations do not expire.

Returns:

  • (Time)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#instrumentation_typeString

The type of instrumentation that was created, echoed from the request.

Returns:

  • (String)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

The location where instrumentation is applied, echoed from the request.

Returns:



1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#location_hashString

A stable hash computed from the location that uniquely identifies this instrumentation point within the service, environment, and signal type.

Returns:

  • (String)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service name for the instrumentation configuration, echoed from the request.

Returns:

  • (String)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

The telemetry signal type for the instrumentation configuration, echoed from the request.

Returns:

  • (String)


1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006

class CreateInstrumentationConfigurationResponse < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end