Class: Aws::ApplicationSignals::Types::CreateServiceLevelObjectiveInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::CreateServiceLevelObjectiveInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#burn_rate_configurations ⇒ Array<Types::BurnRateConfiguration>
Use this array to create *burn rates* for this SLO.
-
#create_recommended_slo ⇒ Boolean
Set this to ‘true` to create a recommended SLO out of the box.
-
#description ⇒ String
An optional description for this SLO.
-
#goal ⇒ Types::Goal
This structure contains the attributes that determine the goal of the SLO.
-
#name ⇒ String
A name for this SLO.
-
#request_based_sli_config ⇒ Types::RequestBasedServiceLevelIndicatorConfig
If this SLO is a request-based SLO, this structure defines the information about what performance metric this SLO will monitor.
-
#sli_config ⇒ Types::ServiceLevelIndicatorConfig
If this SLO is a period-based SLO, this structure defines the information about what performance metric this SLO will monitor.
-
#tags ⇒ Array<Types::Tag>
A list of key-value pairs to associate with the SLO.
Instance Attribute Details
#burn_rate_configurations ⇒ Array<Types::BurnRateConfiguration>
Use this array to create *burn rates* for this SLO. Each burn rate is a metric that indicates how fast the service is consuming the error budget, relative to the attainment goal of the SLO.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |
#create_recommended_slo ⇒ Boolean
Set this to ‘true` to create a recommended SLO out of the box. When set to `true`, you don’t need to specify the ‘MetricThreshold` or `ComparisonOperator` in the `SliConfig` or `RequestBasedSliConfig`. The default value is `false`.
This is supported for SLOs on a service, service operation, or a dependency.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional description for this SLO.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |
#goal ⇒ Types::Goal
This structure contains the attributes that determine the goal of the SLO.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for this SLO.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |
#request_based_sli_config ⇒ Types::RequestBasedServiceLevelIndicatorConfig
If this SLO is a request-based SLO, this structure defines the information about what performance metric this SLO will monitor.
You can’t specify both ‘RequestBasedSliConfig` and `SliConfig` in the same operation.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |
#sli_config ⇒ Types::ServiceLevelIndicatorConfig
If this SLO is a period-based SLO, this structure defines the information about what performance metric this SLO will monitor.
You can’t specify both ‘RequestBasedSliConfig` and `SliConfig` in the same operation.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of key-value pairs to associate with the SLO. You can associate as many as 50 tags with an SLO. To be able to associate tags with the SLO when you create the SLO, you must have the ‘cloudwatch:TagResource` permission.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 547 class CreateServiceLevelObjectiveInput < Struct.new( :name, :description, :sli_config, :request_based_sli_config, :goal, :tags, :burn_rate_configurations, :create_recommended_slo) SENSITIVE = [] include Aws::Structure end |