Class: Aws::ApplicationSignals::Types::Edge
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::Edge
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
A structure that represents a connection between two nodes in a dependency graph, showing the relationship and characteristics of the connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_type ⇒ String
The type of connection between the nodes, indicating the nature of the relationship.
-
#destination_node_id ⇒ String
The identifier of the destination node in this edge connection.
-
#duration ⇒ Float
The duration or latency associated with this connection, if applicable.
-
#source_node_id ⇒ String
The identifier of the source node in this edge connection.
Instance Attribute Details
#connection_type ⇒ String
The type of connection between the nodes, indicating the nature of the relationship.
716 717 718 719 720 721 722 723 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 716 class Edge < Struct.new( :source_node_id, :destination_node_id, :duration, :connection_type) SENSITIVE = [] include Aws::Structure end |
#destination_node_id ⇒ String
The identifier of the destination node in this edge connection.
716 717 718 719 720 721 722 723 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 716 class Edge < Struct.new( :source_node_id, :destination_node_id, :duration, :connection_type) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Float
The duration or latency associated with this connection, if applicable.
716 717 718 719 720 721 722 723 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 716 class Edge < Struct.new( :source_node_id, :destination_node_id, :duration, :connection_type) SENSITIVE = [] include Aws::Structure end |
#source_node_id ⇒ String
The identifier of the source node in this edge connection.
716 717 718 719 720 721 722 723 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 716 class Edge < Struct.new( :source_node_id, :destination_node_id, :duration, :connection_type) SENSITIVE = [] include Aws::Structure end |