Class: Aws::ApplicationSignals::Types::GetInstrumentationConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::GetInstrumentationConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::InstrumentationConfiguration
The complete instrumentation configuration, including its location hash, capture settings, filters, expiration, and creation time.
Instance Attribute Details
#configuration ⇒ Types::InstrumentationConfiguration
The complete instrumentation configuration, including its location hash, capture settings, filters, expiration, and creation time.
1387 1388 1389 1390 1391 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1387 class GetInstrumentationConfigurationResponse < Struct.new( :configuration) SENSITIVE = [] include Aws::Structure end |