Class: Aws::ApplicationSignals::Types::GetInstrumentationConfigurationStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The end of the time range to retrieve status events for. ‘StartTime` and `EndTime` must both be provided together or both be omitted. When both are omitted, the time range defaults to the last hour.

Returns:

  • (Time)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#environmentString

Environment name for the instrumentation configuration.

Returns:

  • (String)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#instrumentation_typeString

Type of instrumentation configuration (BREAKPOINT or PROBE). Required to identify the configuration to retrieve.

Returns:

  • (String)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#location_identifierTypes::LocationIdentifier

Location identifier - either full code location or a pre-computed hash.



1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of status events to return in one call. The default is 60.

Returns:

  • (Integer)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Use the token returned by a previous call to retrieve the next page of status events.

Returns:

  • (String)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

Service name for the instrumentation configuration.

Returns:

  • (String)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

Signal type for the instrumentation configuration.

Returns:

  • (String)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start of the time range to retrieve status events for. ‘StartTime` and `EndTime` must both be provided together or both be omitted. When both are omitted, the time range defaults to the last hour.

Returns:

  • (Time)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The single status to query for. If omitted, only ‘ACTIVE` status events are returned.

Returns:

  • (String)


1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445

class GetInstrumentationConfigurationStatusRequest < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location_identifier,
  :status,
  :start_time,
  :end_time,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end