Class: Aws::ApplicationSignals::Types::GetInstrumentationConfigurationStatusResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#environmentString

The environment echoed from the request.

Returns:

  • (String)


1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492

class GetInstrumentationConfigurationStatusResponse < Struct.new(
  :service,
  :environment,
  :signal_type,
  :location,
  :status,
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#eventsArray<Types::InstrumentationStatusEvent>

The list of status events within the requested time window, sorted with the most recent first. Error events include an error cause.



1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492

class GetInstrumentationConfigurationStatusResponse < Struct.new(
  :service,
  :environment,
  :signal_type,
  :location,
  :status,
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

The code location echoed from the request.

Returns:



1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492

class GetInstrumentationConfigurationStatusResponse < Struct.new(
  :service,
  :environment,
  :signal_type,
  :location,
  :status,
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Pagination token to continue retrieving status events.

Returns:

  • (String)


1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492

class GetInstrumentationConfigurationStatusResponse < Struct.new(
  :service,
  :environment,
  :signal_type,
  :location,
  :status,
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service name echoed from the request.

Returns:

  • (String)


1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492

class GetInstrumentationConfigurationStatusResponse < Struct.new(
  :service,
  :environment,
  :signal_type,
  :location,
  :status,
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

The telemetry signal type echoed from the request.

Returns:

  • (String)


1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492

class GetInstrumentationConfigurationStatusResponse < Struct.new(
  :service,
  :environment,
  :signal_type,
  :location,
  :status,
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status that was queried. If not specified in the request, this is ‘ACTIVE`.

Returns:

  • (String)


1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492

class GetInstrumentationConfigurationStatusResponse < Struct.new(
  :service,
  :environment,
  :signal_type,
  :location,
  :status,
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end