Class: Aws::ApplicationSignals::Types::GetServiceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::GetServiceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The end of the time period to retrieve information about.
-
#key_attributes ⇒ Hash<String,String>
Use this field to specify which service you want to retrieve information for.
-
#start_time ⇒ Time
The start of the time period to retrieve information about.
Instance Attribute Details
#end_time ⇒ Time
The end of the time period to retrieve information about. When used
in a raw HTTP Query API, it is formatted as be epoch time in
seconds. For example: 1698778057
Your requested start time will be rounded to the nearest hour.
1547 1548 1549 1550 1551 1552 1553 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1547 class GetServiceInput < Struct.new( :start_time, :end_time, :key_attributes) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
Use this field to specify which service you want to retrieve
information for. You must specify at least the Type, Name, and
Environment attributes.
This is a string-to-string map. It can include the following fields.
-
Typedesignates the type of object this is. -
ResourceTypespecifies the type of the resource. This field is used only when the value of theTypefield isResourceorAWS::Resource. -
Namespecifies the name of the object. This is used only if the value of theTypefield isService,RemoteService, orAWS::Service. -
Identifieridentifies the resource objects of this resource. This is used only if the value of theTypefield isResourceorAWS::Resource. -
Environmentspecifies the location where this object is hosted, or what it belongs to.
1547 1548 1549 1550 1551 1552 1553 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1547 class GetServiceInput < Struct.new( :start_time, :end_time, :key_attributes) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start of the time period to retrieve information about. When
used in a raw HTTP Query API, it is formatted as be epoch time in
seconds. For example: 1698778057
Your requested start time will be rounded to the nearest hour.
1547 1548 1549 1550 1551 1552 1553 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1547 class GetServiceInput < Struct.new( :start_time, :end_time, :key_attributes) SENSITIVE = [] include Aws::Structure end |