Class: Aws::ApplicationSignals::Types::GetServiceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::GetServiceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The end time of the data included in the response.
-
#log_group_references ⇒ Array<Hash<String,String>>
An array of string-to-string maps that each contain information about one log group associated with this service.
-
#service ⇒ Types::Service
A structure containing information about the service.
-
#start_time ⇒ Time
The start time of the data included in the response.
Instance Attribute Details
#end_time ⇒ Time
The end time of the data included in the response. In a raw HTTP Query API, it is formatted as be epoch time in seconds. For example: ‘1698778057`.
This displays the time that Application Signals used for the request. It might not match your request exactly, because it was rounded to the nearest hour.
877 878 879 880 881 882 883 884 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 877 class GetServiceOutput < Struct.new( :service, :start_time, :end_time, :log_group_references) SENSITIVE = [] include Aws::Structure end |
#log_group_references ⇒ Array<Hash<String,String>>
An array of string-to-string maps that each contain information about one log group associated with this service. Each string-to-string map includes the following fields:
-
‘“Type”: “AWS::Resource”`
-
‘“ResourceType”: “AWS::Logs::LogGroup”`
-
‘“Identifier”: “name-of-log-group”`
877 878 879 880 881 882 883 884 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 877 class GetServiceOutput < Struct.new( :service, :start_time, :end_time, :log_group_references) SENSITIVE = [] include Aws::Structure end |
#service ⇒ Types::Service
A structure containing information about the service.
877 878 879 880 881 882 883 884 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 877 class GetServiceOutput < Struct.new( :service, :start_time, :end_time, :log_group_references) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the data included in the response. In a raw HTTP Query API, it is formatted as be epoch time in seconds. For example: ‘1698778057`.
This displays the time that Application Signals used for the request. It might not match your request exactly, because it was rounded to the nearest hour.
877 878 879 880 881 882 883 884 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 877 class GetServiceOutput < Struct.new( :service, :start_time, :end_time, :log_group_references) SENSITIVE = [] include Aws::Structure end |