Class: Aws::ApplicationSignals::Types::GroupingAttributeDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::GroupingAttributeDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
A structure that defines how services should be grouped based on specific attributes. This includes the friendly name for the grouping, the source keys to derive values from, and an optional default value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_grouping_value ⇒ String
The default value to use for this grouping attribute when no value can be derived from the source keys.
-
#grouping_name ⇒ String
The friendly name for this grouping attribute, such as ‘BusinessUnit` or `Environment`.
-
#grouping_source_keys ⇒ Array<String>
An array of source keys used to derive the grouping attribute value from telemetry data, Amazon Web Services tags, or other sources.
Instance Attribute Details
#default_grouping_value ⇒ String
The default value to use for this grouping attribute when no value can be derived from the source keys. This ensures all services have a grouping value even if the source data is missing.
1013 1014 1015 1016 1017 1018 1019 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1013 class GroupingAttributeDefinition < Struct.new( :grouping_name, :grouping_source_keys, :default_grouping_value) SENSITIVE = [] include Aws::Structure end |
#grouping_name ⇒ String
The friendly name for this grouping attribute, such as ‘BusinessUnit` or `Environment`. This name is used to identify the grouping in the console and APIs.
1013 1014 1015 1016 1017 1018 1019 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1013 class GroupingAttributeDefinition < Struct.new( :grouping_name, :grouping_source_keys, :default_grouping_value) SENSITIVE = [] include Aws::Structure end |
#grouping_source_keys ⇒ Array<String>
An array of source keys used to derive the grouping attribute value from telemetry data, Amazon Web Services tags, or other sources. For example, [“business_unit”, “team”] would look for values in those fields.
1013 1014 1015 1016 1017 1018 1019 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1013 class GroupingAttributeDefinition < Struct.new( :grouping_name, :grouping_source_keys, :default_grouping_value) SENSITIVE = [] include Aws::Structure end |