Class: Aws::ApplicationSignals::Types::InstrumentationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

The full instrumentation configuration, including the instrumentation type, service, environment, signal type, location details, stable location hash, capture settings, filters, expiration, creation time, and ARN.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

ARN for the instrumentation configuration

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#attribute_filtersArray<Hash<String,String>>

Client-side filters that determine which instances apply this instrumentation.

Returns:

  • (Array<Hash<String,String>>)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#capture_configurationTypes::CaptureConfiguration

The capture settings for this instrumentation configuration.



1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when this instrumentation configuration was created.

Returns:

  • (Time)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional short description of the instrumentation configuration.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#environmentString

The environment where the service is running.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

The timestamp when this configuration expires.

Returns:

  • (Time)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#instrumentation_typeString

The type of instrumentation for this configuration.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

The location where this instrumentation is applied.

Returns:



1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#location_hashString

The stable hash derived from the location that uniquely identifies this instrumentation point within the service and environment.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service that this instrumentation configuration targets.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

The telemetry signal type for this instrumentation configuration.

Returns:

  • (String)


1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790

class InstrumentationConfiguration < Struct.new(
  :instrumentation_type,
  :service,
  :environment,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end