Class: Aws::ApplicationSignals::Types::InstrumentationConfigurationStatusReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::InstrumentationConfigurationStatusReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
The status of a single instrumentation configuration reported by an SDK instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_cause ⇒ String
The error cause when the status is ‘ERROR`, such as the file or method not being found.
-
#instrumentation_type ⇒ String
The type of instrumentation configuration being reported.
-
#location_hash ⇒ String
The stable hash of the instrumentation location that identifies the configuration being reported.
-
#signal_type ⇒ String
The telemetry signal type for this instrumentation configuration.
-
#status ⇒ String
The status of the instrumentation configuration: ‘READY`, `ERROR`, `ACTIVE`, or `DISABLED`.
-
#time ⇒ Time
The timestamp when the status event occurred.
Instance Attribute Details
#error_cause ⇒ String
The error cause when the status is ‘ERROR`, such as the file or method not being found.
1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1839 class InstrumentationConfigurationStatusReport < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :error_cause) SENSITIVE = [] include Aws::Structure end |
#instrumentation_type ⇒ String
The type of instrumentation configuration being reported.
1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1839 class InstrumentationConfigurationStatusReport < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :error_cause) SENSITIVE = [] include Aws::Structure end |
#location_hash ⇒ String
The stable hash of the instrumentation location that identifies the configuration being reported.
1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1839 class InstrumentationConfigurationStatusReport < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :error_cause) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
The telemetry signal type for this instrumentation configuration.
1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1839 class InstrumentationConfigurationStatusReport < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :error_cause) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the instrumentation configuration: ‘READY`, `ERROR`, `ACTIVE`, or `DISABLED`.
1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1839 class InstrumentationConfigurationStatusReport < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :error_cause) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Time
The timestamp when the status event occurred.
1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1839 class InstrumentationConfigurationStatusReport < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :error_cause) SENSITIVE = [] include Aws::Structure end |