Class: Aws::ApplicationSignals::Types::InstrumentationConfigurationWithoutServiceEnv

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

An instrumentation configuration that omits service and environment because they are provided at a higher level, such as in a list response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

ARN for the instrumentation configuration

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#attribute_filtersArray<Hash<String,String>>

Client-side filters that determine which instances apply this instrumentation.

Returns:

  • (Array<Hash<String,String>>)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#capture_configurationTypes::CaptureConfiguration

The capture settings for this instrumentation configuration.



1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when this instrumentation configuration was created.

Returns:

  • (Time)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional short description of the instrumentation configuration.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

The timestamp when this configuration expires.

Returns:

  • (Time)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#instrumentation_typeString

The type of instrumentation for this configuration.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

The location where this instrumentation is applied.

Returns:



1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#location_hashString

The stable hash derived from the location that identifies this instrumentation point.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

The telemetry signal type for this instrumentation configuration.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898

class InstrumentationConfigurationWithoutServiceEnv < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location,
  :location_hash,
  :description,
  :expires_at,
  :attribute_filters,
  :capture_configuration,
  :created_at,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end