Class: Aws::ApplicationSignals::Types::InstrumentationConfigurationsPage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#changedBoolean

Indicates whether there are configuration changes since the provided ‘SyncedAt` timestamp.

Returns:

  • (Boolean)


1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948

class InstrumentationConfigurationsPage < Struct.new(
  :service,
  :environment,
  :changed,
  :latest_configurations,
  :synced_at,
  :sync_interval,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#environmentString

The environment associated with the returned configurations.

Returns:

  • (String)


1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948

class InstrumentationConfigurationsPage < Struct.new(
  :service,
  :environment,
  :changed,
  :latest_configurations,
  :synced_at,
  :sync_interval,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#latest_configurationsArray<Types::InstrumentationConfigurationWithoutServiceEnv>

The current set of active instrumentation configurations for the service and environment. Items omit service and environment because they are provided in the request.



1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948

class InstrumentationConfigurationsPage < Struct.new(
  :service,
  :environment,
  :changed,
  :latest_configurations,
  :synced_at,
  :sync_interval,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Pagination token to continue listing configurations when more results are available.

Returns:

  • (String)


1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948

class InstrumentationConfigurationsPage < Struct.new(
  :service,
  :environment,
  :changed,
  :latest_configurations,
  :synced_at,
  :sync_interval,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

The service name associated with the returned configurations.

Returns:

  • (String)


1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948

class InstrumentationConfigurationsPage < Struct.new(
  :service,
  :environment,
  :changed,
  :latest_configurations,
  :synced_at,
  :sync_interval,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sync_intervalInteger

The suggested number of seconds to wait before the next sync request. This is at least 60 seconds to prevent excessive polling.

Returns:

  • (Integer)


1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948

class InstrumentationConfigurationsPage < Struct.new(
  :service,
  :environment,
  :changed,
  :latest_configurations,
  :synced_at,
  :sync_interval,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#synced_atTime

The server timestamp to supply on the next sync call.

Returns:

  • (Time)


1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948

class InstrumentationConfigurationsPage < Struct.new(
  :service,
  :environment,
  :changed,
  :latest_configurations,
  :synced_at,
  :sync_interval,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end