Class: Aws::ApplicationSignals::Types::InstrumentationStatusEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

A status event for an instrumentation configuration returned by ‘GetInstrumentationConfigurationStatus`. Events include the timestamp and, for errors, an error cause.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_causeString

The error cause when the status is ‘ERROR`.

Returns:

  • (String)


1975
1976
1977
1978
1979
1980
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1975

class InstrumentationStatusEvent < Struct.new(
  :time,
  :error_cause)
  SENSITIVE = []
  include Aws::Structure
end

#timeTime

The time when the status was reported, rounded to the nearest minute.

Returns:

  • (Time)


1975
1976
1977
1978
1979
1980
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1975

class InstrumentationStatusEvent < Struct.new(
  :time,
  :error_cause)
  SENSITIVE = []
  include Aws::Structure
end