Class: Aws::ApplicationSignals::Types::Location
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::Location
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Location is a union - when making an API calls you must set exactly one of the members.
Location is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Location corresponding to the set member.
A union that identifies the location to instrument. Specify a ‘CodeLocation` for code-level instrumentation.
Direct Known Subclasses
Defined Under Namespace
Classes: CodeLocation, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_location ⇒ Types::CodeLocation
A code location for code-level instrumentation, including language, code unit, class, method, file path, and optional line number.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#code_location ⇒ Types::CodeLocation
A code location for code-level instrumentation, including language, code unit, class, method, file path, and optional line number.
3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3047 class Location < Struct.new( :code_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CodeLocation < Location; end class Unknown < Location; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3047 3048 3049 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3047 def unknown @unknown end |