Class: Aws::ApplicationSignals::Types::LocationIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Note:

LocationIdentifier is a union - when making an API calls you must set exactly one of the members.

Union type for identifying an instrumentation configuration by code location or locationHash. Used in Get/Delete/GetStatus operations to allow flexible identification.

Direct Known Subclasses

CodeLocation, LocationHash, Unknown

Defined Under Namespace

Classes: CodeLocation, LocationHash, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_locationTypes::CodeLocation

The full code location specification (will be hashed internally)

Returns:



3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3074

class LocationIdentifier < Struct.new(
  :code_location,
  :location_hash,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CodeLocation < LocationIdentifier; end
  class LocationHash < LocationIdentifier; end
  class Unknown < LocationIdentifier; end
end

#location_hashString

The pre-computed location hash (16-character hex string)

Returns:

  • (String)


3074
3075
3076
3077
3078
3079
3080
3081
3082
3083
3084
3085
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3074

class LocationIdentifier < Struct.new(
  :code_location,
  :location_hash,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class CodeLocation < LocationIdentifier; end
  class LocationHash < LocationIdentifier; end
  class Unknown < LocationIdentifier; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3074
3075
3076
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3074

def unknown
  @unknown
end