Class: Aws::ApplicationSignals::Types::MetricReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::MetricReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure contains information about one CloudWatch metric associated with this entity discovered by Application Signals.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
Amazon Web Services account ID.
-
#dimensions ⇒ Array<Types::Dimension>
An array of one or more dimensions that further define the metric.
-
#metric_name ⇒ String
The name of the metric.
-
#metric_type ⇒ String
Used to display the appropriate statistics in the CloudWatch console.
-
#namespace ⇒ String
The namespace of the metric.
Instance Attribute Details
#account_id ⇒ String
Amazon Web Services account ID.
2280 2281 2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2280 class MetricReference < Struct.new( :namespace, :metric_type, :dimensions, :metric_name, :account_id) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Array<Types::Dimension>
An array of one or more dimensions that further define the metric. For more information, see [CloudWatchDimensions].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Dimension
2280 2281 2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2280 class MetricReference < Struct.new( :namespace, :metric_type, :dimensions, :metric_name, :account_id) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric.
2280 2281 2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2280 class MetricReference < Struct.new( :namespace, :metric_type, :dimensions, :metric_name, :account_id) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
Used to display the appropriate statistics in the CloudWatch console.
2280 2281 2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2280 class MetricReference < Struct.new( :namespace, :metric_type, :dimensions, :metric_name, :account_id) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace of the metric. For more information, see [CloudWatchNamespaces].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Namespace
2280 2281 2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2280 class MetricReference < Struct.new( :namespace, :metric_type, :dimensions, :metric_name, :account_id) SENSITIVE = [] include Aws::Structure end |