Class: Aws::ApplicationSignals::Types::MonitoredRequestCountMetricDataQueries
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::MonitoredRequestCountMetricDataQueries
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
MonitoredRequestCountMetricDataQueries is a union - when making an API calls you must set exactly one of the members.
MonitoredRequestCountMetricDataQueries is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of MonitoredRequestCountMetricDataQueries corresponding to the set member.
This structure defines the metric that is used as the "good request"
or "bad request" value for a request-based SLO. This value observed
for the metric defined in TotalRequestCountMetric is divided by the
number found for MonitoredRequestCountMetric to determine the
percentage of successful requests that this SLO tracks.
Defined Under Namespace
Classes: BadCountMetric, GoodCountMetric, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bad_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count "bad requests" to determine the percentage of successful requests for this request-based SLO, specify the metric to use as "bad requests" in this structure.
-
#good_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count "good requests" to determine the percentage of successful requests for this request-based SLO, specify the metric to use as "good requests" in this structure.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#bad_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count "bad requests" to determine the percentage of successful requests for this request-based SLO, specify the metric to use as "bad requests" in this structure.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3417 class MonitoredRequestCountMetricDataQueries < Struct.new( :good_count_metric, :bad_count_metric, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GoodCountMetric < MonitoredRequestCountMetricDataQueries; end class BadCountMetric < MonitoredRequestCountMetricDataQueries; end class Unknown < MonitoredRequestCountMetricDataQueries; end end |
#good_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count "good requests" to determine the percentage of successful requests for this request-based SLO, specify the metric to use as "good requests" in this structure.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3417 class MonitoredRequestCountMetricDataQueries < Struct.new( :good_count_metric, :bad_count_metric, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GoodCountMetric < MonitoredRequestCountMetricDataQueries; end class BadCountMetric < MonitoredRequestCountMetricDataQueries; end class Unknown < MonitoredRequestCountMetricDataQueries; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3417 3418 3419 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3417 def unknown @unknown end |