Class: Aws::ApplicationSignals::Types::Node

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

A structure that represents a node in a dependency graph, containing information about a service, resource, or other entity and its characteristics.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durationFloat

The duration or processing time associated with this node, if applicable.

Returns:

  • (Float)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375

class Node < Struct.new(
  :key_attributes,
  :name,
  :node_id,
  :operation,
  :type,
  :duration,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#key_attributesHash<String,String>

The key attributes that identify this node, including Type, Name, and Environment information.

Returns:

  • (Hash<String,String>)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375

class Node < Struct.new(
  :key_attributes,
  :name,
  :node_id,
  :operation,
  :type,
  :duration,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the entity represented by this node.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375

class Node < Struct.new(
  :key_attributes,
  :name,
  :node_id,
  :operation,
  :type,
  :duration,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#node_idString

A unique identifier for this node within the dependency graph.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375

class Node < Struct.new(
  :key_attributes,
  :name,
  :node_id,
  :operation,
  :type,
  :duration,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#operationString

The operation associated with this node, if applicable.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375

class Node < Struct.new(
  :key_attributes,
  :name,
  :node_id,
  :operation,
  :type,
  :duration,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the entity represented by this node.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375

class Node < Struct.new(
  :key_attributes,
  :name,
  :node_id,
  :operation,
  :type,
  :duration,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of entity represented by this node, such as ‘Service` or `Resource`.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375

class Node < Struct.new(
  :key_attributes,
  :name,
  :node_id,
  :operation,
  :type,
  :duration,
  :status)
  SENSITIVE = []
  include Aws::Structure
end