Class: Aws::ApplicationSignals::Types::ReportInstrumentationConfigurationStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::ReportInstrumentationConfigurationStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configurations ⇒ Array<Types::InstrumentationConfigurationStatusReport>
An array of configuration status reports (up to 100) that include the instrumentation type, signal type, location hash, status, timestamp, and optional error cause.
-
#environment ⇒ String
The environment that the service is running in.
-
#service ⇒ String
The service that the reported configurations belong to.
Instance Attribute Details
#configurations ⇒ Array<Types::InstrumentationConfigurationStatusReport>
An array of configuration status reports (up to 100) that include the instrumentation type, signal type, location hash, status, timestamp, and optional error cause.
3539 3540 3541 3542 3543 3544 3545 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3539 class ReportInstrumentationConfigurationStatusRequest < Struct.new( :service, :environment, :configurations) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ String
The environment that the service is running in.
3539 3540 3541 3542 3543 3544 3545 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3539 class ReportInstrumentationConfigurationStatusRequest < Struct.new( :service, :environment, :configurations) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service that the reported configurations belong to.
3539 3540 3541 3542 3543 3544 3545 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3539 class ReportInstrumentationConfigurationStatusRequest < Struct.new( :service, :environment, :configurations) SENSITIVE = [] include Aws::Structure end |