Class: Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

This structure contains information about the performance metric that a request-based SLO monitors.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#comparison_operatorString

The arithmetic operation used when comparing the specified metric to the threshold.

Returns:

  • (String)


2451
2452
2453
2454
2455
2456
2457
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2451

class RequestBasedServiceLevelIndicator < Struct.new(
  :request_based_sli_metric,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end

#metric_thresholdFloat

This value is the threshold that the observed metric values of the SLI metric are compared to.

Returns:

  • (Float)


2451
2452
2453
2454
2455
2456
2457
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2451

class RequestBasedServiceLevelIndicator < Struct.new(
  :request_based_sli_metric,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end

#request_based_sli_metricTypes::RequestBasedServiceLevelIndicatorMetric

A structure that contains information about the metric that the SLO monitors.



2451
2452
2453
2454
2455
2456
2457
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2451

class RequestBasedServiceLevelIndicator < Struct.new(
  :request_based_sli_metric,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end