Class: Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure specifies the information about the service and the performance metric that a request-based SLO is to monitor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the specified metric to the threshold.
-
#metric_threshold ⇒ Float
The value that the SLI metric is compared to.
-
#request_based_sli_metric_config ⇒ Types::RequestBasedServiceLevelIndicatorMetricConfig
Use this structure to specify the metric to be used for the SLO.
Instance Attribute Details
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the specified metric
to the threshold. This parameter is required if this SLO is tracking
the Latency metric.
3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3619 class RequestBasedServiceLevelIndicatorConfig < Struct.new( :request_based_sli_metric_config, :metric_threshold, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#metric_threshold ⇒ Float
The value that the SLI metric is compared to. This parameter is
required if this SLO is tracking the Latency metric.
3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3619 class RequestBasedServiceLevelIndicatorConfig < Struct.new( :request_based_sli_metric_config, :metric_threshold, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#request_based_sli_metric_config ⇒ Types::RequestBasedServiceLevelIndicatorMetricConfig
Use this structure to specify the metric to be used for the SLO.
3619 3620 3621 3622 3623 3624 3625 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3619 class RequestBasedServiceLevelIndicatorConfig < Struct.new( :request_based_sli_metric_config, :metric_threshold, :comparison_operator) SENSITIVE = [] include Aws::Structure end |