Class: Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure contains the information about the metric that is used for a request-based SLO.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#composite_sli_config ⇒ Types::CompositeSliConfig
The composite SLI configuration for service-level SLOs that monitor multiple operations of a service.
-
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the
DependencyKeyAttributesandDependencyOperationName. -
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to.
-
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
-
#metric_type ⇒ String
If the SLO monitors either the
LATENCYorAVAILABILITYmetric that Application Signals collects, this field displays which of those metrics is used. -
#monitored_request_count_metric ⇒ Types::MonitoredRequestCountMetricDataQueries
This structure defines the metric that is used as the "good request" or "bad request" value for a request-based SLO.
-
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
-
#total_request_count_metric ⇒ Array<Types::MetricDataQuery>
This structure defines the metric that is used as the "total requests" number for a request-based SLO.
Instance Attribute Details
#composite_sli_config ⇒ Types::CompositeSliConfig
The composite SLI configuration for service-level SLOs that monitor multiple operations of a service.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the DependencyKeyAttributes and
DependencyOperationName.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to. It can include the following fields.
-
Typedesignates the type of object that this SLO is related to. -
ResourceTypespecifies the type of the resource. This field is used only when the value of theTypefield isResourceorAWS::Resource. -
Namespecifies the name of the object. This is used only if the value of theTypefield isService,RemoteService, orAWS::Service. -
Identifieridentifies the resource objects of this resource. This is used only if the value of theTypefield isResourceorAWS::Resource. -
Environmentspecifies the location where this object is hosted, or what it belongs to.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
If the SLO monitors either the LATENCY or AVAILABILITY metric
that Application Signals collects, this field displays which of
those metrics is used.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#monitored_request_count_metric ⇒ Types::MonitoredRequestCountMetricDataQueries
This structure defines the metric that is used as the "good
request" or "bad request" value for a request-based SLO. This
value observed for the metric defined in TotalRequestCountMetric
is divided by the number found for MonitoredRequestCountMetric to
determine the percentage of successful requests that this SLO
tracks.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#total_request_count_metric ⇒ Array<Types::MetricDataQuery>
This structure defines the metric that is used as the "total
requests" number for a request-based SLO. The number observed for
this metric is divided by the number of "good requests" or "bad
requests" that is observed for the metric defined in
MonitoredRequestCountMetric.
3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3698 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |