Class: Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorMetricConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Use this structure to specify the information for the metric that a period-based SLO will monitor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#composite_sli_configTypes::CompositeSliConfig

The composite SLI configuration for service-level SLOs that monitor multiple operations of a service.



3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#dependency_configTypes::DependencyConfig

Identifies the dependency using the DependencyKeyAttributes and DependencyOperationName.



3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#key_attributesHash<String,String>

If this SLO is related to a metric collected by Application Signals, you must use this field to specify which service the SLO metric is related to. To do so, you must specify at least the Type, Name, and Environment attributes.

This is a string-to-string map. It can include the following fields.

  • Type designates the type of object this is.

  • ResourceType specifies the type of the resource. This field is used only when the value of the Type field is Resource or AWS::Resource.

  • Name specifies the name of the object. This is used only if the value of the Type field is Service, RemoteService, or AWS::Service.

  • Identifier identifies the resource objects of this resource. This is used only if the value of the Type field is Resource or AWS::Resource.

  • Environment specifies the location where this object is hosted, or what it belongs to.

Returns:

  • (Hash<String,String>)


3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the metric for SLOs on resources other than Application Signals services.

Returns:

  • (String)


3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#metric_sourceTypes::MetricSource

Identifies the metric source for SLOs on resources other than Application Signals services.

Returns:



3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#metric_typeString

If the SLO is to monitor either the LATENCY or AVAILABILITY metric that Application Signals collects, use this field to specify which of those metrics is used.

Returns:

  • (String)


3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#monitored_request_count_metricTypes::MonitoredRequestCountMetricDataQueries

Use this structure to define the metric that you want to use as the "good request" or "bad request" value for a request-based SLO. This value observed for the metric defined in TotalRequestCountMetric will be divided by the number found for MonitoredRequestCountMetric to determine the percentage of successful requests that this SLO tracks.



3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#operation_nameString

If the SLO is to monitor a specific operation of the service, use this field to specify the name of that operation.

Returns:

  • (String)


3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end

#total_request_count_metricArray<Types::MetricDataQuery>

Use this structure to define the metric that you want to use as the "total requests" number for a request-based SLO. This result will be divided by the "good request" or "bad request" value defined in MonitoredRequestCountMetric.

Returns:



3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789

class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :total_request_count_metric,
  :monitored_request_count_metric,
  :dependency_config,
  :metric_source,
  :metric_name,
  :composite_sli_config)
  SENSITIVE = []
  include Aws::Structure
end