Class: Aws::ApplicationSignals::Types::SelectionConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Defines how operations are selected for a service-level SLO.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#patternString

A prefix string or regular expression that specifies which operations to include in a service-level SLO. When ‘SelectionType` is `PREFIX`, this value is a prefix string that matches the beginning of operation names. When `SelectionType` is `REGEX`, this value is a regular expression that matches operation names.

Returns:

  • (String)


2794
2795
2796
2797
2798
2799
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2794

class SelectionConfig < Struct.new(
  :type,
  :pattern)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The strategy for selecting operations to include in a service-level SLO.

  • ‘EXPLICIT` — You provide a specific list of operations in the `Components` field of `CompositeSliConfig`.

  • ‘PREFIX` — You provide a prefix string in the `Pattern` field of `SelectionConfig`, and all operations whose names start with the prefix are included.

  • ‘REGEX` — You provide a regular expression in the `Pattern` field of `SelectionConfig`, and all operations whose names match the pattern are included.

Returns:

  • (String)


2794
2795
2796
2797
2798
2799
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2794

class SelectionConfig < Struct.new(
  :type,
  :pattern)
  SENSITIVE = []
  include Aws::Structure
end