Class: Aws::ApplicationSignals::Types::Service
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::Service
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure contains information about one of your services that was discovered by Application Signals.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_maps ⇒ Array<Hash<String,String>>
This structure contains one or more string-to-string maps that help identify this service.
-
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map.
-
#log_group_references ⇒ Array<Hash<String,String>>
An array of string-to-string maps that each contain information about one log group associated with this service.
-
#metric_references ⇒ Array<Types::MetricReference>
An array of structures that each contain information about one metric associated with this service.
-
#service_groups ⇒ Array<Types::ServiceGroup>
An array of service groups that this service belongs to, based on the configured grouping attributes.
Instance Attribute Details
#attribute_maps ⇒ Array<Hash<String,String>>
This structure contains one or more string-to-string maps that help identify this service. It can include platform attributes, application attributes, and telemetry attributes.
Platform attributes contain information the service's platform.
-
PlatformTypedefines the hosted-in platform. -
EKS.Clusteris the name of the Amazon EKS cluster. -
K8s.Clusteris the name of the self-hosted Kubernetes cluster. -
K8s.Namespaceis the name of the Kubernetes namespace in either Amazon EKS or Kubernetes clusters. -
K8s.Workloadis the name of the Kubernetes workload in either Amazon EKS or Kubernetes clusters. -
K8s.Nodeis the name of the Kubernetes node in either Amazon EKS or Kubernetes clusters. -
K8s.Podis the name of the Kubernetes pod in either Amazon EKS or Kubernetes clusters. -
EC2.AutoScalingGroupis the name of the Amazon EC2 Auto Scaling group. -
EC2.InstanceIdis the ID of the Amazon EC2 instance. -
Hostis the name of the host, for all platform types.
Application attributes contain information about the application.
-
AWS.Applicationis the application's name in Amazon Web Services Service Catalog AppRegistry. -
AWS.Application.ARNis the application's ARN in Amazon Web Services Service Catalog AppRegistry.
Telemetry attributes contain telemetry information.
-
Telemetry.SDKis the fingerprint of the OpenTelemetry SDK version for instrumented services. -
Telemetry.Agentis the fingerprint of the agent used to collect and send telemetry data. -
Telemetry.SourceSpecifies the point of application where the telemetry was collected or specifies what was used for the source of telemetry data.
3984 3985 3986 3987 3988 3989 3990 3991 3992 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3984 class Service < Struct.new( :key_attributes, :attribute_maps, :service_groups, :metric_references, :log_group_references) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map. It can include the following fields.
-
Typedesignates the type of object this is. -
ResourceTypespecifies the type of the resource. This field is used only when the value of theTypefield isResourceorAWS::Resource. -
Namespecifies the name of the object. This is used only if the value of theTypefield isService,RemoteService, orAWS::Service. -
Identifieridentifies the resource objects of this resource. This is used only if the value of theTypefield isResourceorAWS::Resource. -
Environmentspecifies the location where this object is hosted, or what it belongs to.
3984 3985 3986 3987 3988 3989 3990 3991 3992 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3984 class Service < Struct.new( :key_attributes, :attribute_maps, :service_groups, :metric_references, :log_group_references) SENSITIVE = [] include Aws::Structure end |
#log_group_references ⇒ Array<Hash<String,String>>
An array of string-to-string maps that each contain information about one log group associated with this service. Each string-to-string map includes the following fields:
-
"Type": "AWS::Resource" -
"ResourceType": "AWS::Logs::LogGroup" -
"Identifier": "name-of-log-group"
3984 3985 3986 3987 3988 3989 3990 3991 3992 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3984 class Service < Struct.new( :key_attributes, :attribute_maps, :service_groups, :metric_references, :log_group_references) SENSITIVE = [] include Aws::Structure end |
#metric_references ⇒ Array<Types::MetricReference>
An array of structures that each contain information about one metric associated with this service.
3984 3985 3986 3987 3988 3989 3990 3991 3992 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3984 class Service < Struct.new( :key_attributes, :attribute_maps, :service_groups, :metric_references, :log_group_references) SENSITIVE = [] include Aws::Structure end |
#service_groups ⇒ Array<Types::ServiceGroup>
An array of service groups that this service belongs to, based on the configured grouping attributes.
3984 3985 3986 3987 3988 3989 3990 3991 3992 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3984 class Service < Struct.new( :key_attributes, :attribute_maps, :service_groups, :metric_references, :log_group_references) SENSITIVE = [] include Aws::Structure end |