Class: Aws::ApplicationSignals::Types::ServiceLevelIndicator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

This structure contains information about the performance metric that a period-based SLO monitors.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#comparison_operatorString

The arithmetic operation used when comparing the specified metric to the threshold.

Returns:

  • (String)


3099
3100
3101
3102
3103
3104
3105
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3099

class ServiceLevelIndicator < Struct.new(
  :sli_metric,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end

#metric_thresholdFloat

The value that the SLI metric is compared to.

Returns:

  • (Float)


3099
3100
3101
3102
3103
3104
3105
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3099

class ServiceLevelIndicator < Struct.new(
  :sli_metric,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end

#sli_metricTypes::ServiceLevelIndicatorMetric

A structure that contains information about the metric that the SLO monitors.



3099
3100
3101
3102
3103
3104
3105
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3099

class ServiceLevelIndicator < Struct.new(
  :sli_metric,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end