Class: Aws::ApplicationSignals::Types::ServiceLevelIndicatorConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

This structure specifies the information about the service and the performance metric that a period-based SLO is to monitor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#comparison_operatorString

The arithmetic operation to use when comparing the specified metric to the threshold.

This is not required if CreateRecommendedSlo is set to true.

Returns:

  • (String)


4213
4214
4215
4216
4217
4218
4219
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4213

class ServiceLevelIndicatorConfig < Struct.new(
  :sli_metric_config,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end

#metric_thresholdFloat

This parameter is used only when a request-based SLO tracks the Latency metric. Specify the threshold value that the observed Latency metric values are to be compared to.

This is not required if CreateRecommendedSlo is set to true.

Returns:

  • (Float)


4213
4214
4215
4216
4217
4218
4219
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4213

class ServiceLevelIndicatorConfig < Struct.new(
  :sli_metric_config,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end

#sli_metric_configTypes::ServiceLevelIndicatorMetricConfig

Use this structure to specify the metric to be used for the SLO.



4213
4214
4215
4216
4217
4218
4219
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4213

class ServiceLevelIndicatorConfig < Struct.new(
  :sli_metric_config,
  :metric_threshold,
  :comparison_operator)
  SENSITIVE = []
  include Aws::Structure
end