Class: Aws::ApplicationSignals::Types::ServiceLevelIndicatorMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::ServiceLevelIndicatorMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure contains the information about the metric that is used for a period-based SLO.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#composite_sli_config ⇒ Types::CompositeSliConfig
The composite SLI configuration for service-level SLOs that monitor multiple operations of a service.
-
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the
DependencyKeyAttributesandDependencyOperationName. -
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to.
-
#metric_data_queries ⇒ Array<Types::MetricDataQuery>
If this SLO monitors a CloudWatch metric or the result of a CloudWatch metric math expression, this structure includes the information about that metric or expression.
-
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
-
#metric_type ⇒ String
If the SLO monitors either the
LATENCYorAVAILABILITYmetric that Application Signals collects, this field displays which of those metrics is used. -
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
Instance Attribute Details
#composite_sli_config ⇒ Types::CompositeSliConfig
The composite SLI configuration for service-level SLOs that monitor multiple operations of a service.
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4281 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the DependencyKeyAttributes and
DependencyOperationName.
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4281 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to. It can include the following fields.
-
Typedesignates the type of object that this SLO is related to. -
ResourceTypespecifies the type of the resource. This field is used only when the value of theTypefield isResourceorAWS::Resource. -
Namespecifies the name of the object. This is used only if the value of theTypefield isService,RemoteService, orAWS::Service. -
Identifieridentifies the resource objects of this resource. This is used only if the value of theTypefield isResourceorAWS::Resource. -
Environmentspecifies the location where this object is hosted, or what it belongs to.
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4281 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_data_queries ⇒ Array<Types::MetricDataQuery>
If this SLO monitors a CloudWatch metric or the result of a CloudWatch metric math expression, this structure includes the information about that metric or expression.
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4281 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4281 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
If the SLO monitors either the LATENCY or AVAILABILITY metric
that Application Signals collects, this field displays which of
those metrics is used.
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4281 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4281 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |