Class: Aws::ApplicationSignals::Types::ServiceLevelObjective
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::ServiceLevelObjective
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
A structure containing information about one service level objective (SLO) that has been created in Application Signals. Creating SLOs can help you ensure your services are performing to the level that you expect. SLOs help you set and track a specific target level for the reliability and availability of your applications and services. Each SLO uses a service level indicator (SLI), which is a key performance metric, to calculate how much underperformance can be tolerated before the goal that you set for the SLO is not achieved.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of this SLO.
-
#auto_investigation_enabled ⇒ Boolean
Indicates whether DevOps Agent will automatically investigate this SLO when it is breached.
-
#burn_rate_configurations ⇒ Array<Types::BurnRateConfiguration>
Each object in this array defines the length of the look-back window used to calculate one burn rate metric for this SLO.
-
#created_time ⇒ Time
The date and time that this SLO was created.
-
#description ⇒ String
The description that you created for this SLO.
-
#evaluation_type ⇒ String
Displays whether this is a period-based SLO or a request-based SLO.
-
#goal ⇒ Types::Goal
This structure contains the attributes that determine the goal of an SLO.
-
#last_updated_time ⇒ Time
The time that this SLO was most recently updated.
-
#metric_source_type ⇒ String
Displays the SLI metric source type for this SLO.
-
#name ⇒ String
The name of this SLO.
-
#request_based_sli ⇒ Types::RequestBasedServiceLevelIndicator
A structure containing information about the performance metric that this SLO monitors, if this is a request-based SLO.
-
#sli ⇒ Types::ServiceLevelIndicator
A structure containing information about the performance metric that this SLO monitors, if this is a period-based SLO.
Instance Attribute Details
#arn ⇒ String
The ARN of this SLO.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#auto_investigation_enabled ⇒ Boolean
Indicates whether DevOps Agent will automatically investigate this SLO when it is breached
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#burn_rate_configurations ⇒ Array<Types::BurnRateConfiguration>
Each object in this array defines the length of the look-back window used to calculate one burn rate metric for this SLO. The burn rate measures how fast the service is consuming the error budget, relative to the attainment goal of the SLO.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The date and time that this SLO was created. When used in a raw HTTP Query API, it is formatted as ‘yyyy-MM-dd’T’HH:mm:ss`. For example, ‘2019-07-01T23:59:59`.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description that you created for this SLO.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#evaluation_type ⇒ String
Displays whether this is a period-based SLO or a request-based SLO.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#goal ⇒ Types::Goal
This structure contains the attributes that determine the goal of an SLO. This includes the time period for evaluation and the attainment threshold.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The time that this SLO was most recently updated. When used in a raw HTTP Query API, it is formatted as ‘yyyy-MM-dd’T’HH:mm:ss`. For example, ‘2019-07-01T23:59:59`.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#metric_source_type ⇒ String
Displays the SLI metric source type for this SLO. Supported types are:
-
Service operation
-
Service dependency
-
Service
-
CloudWatch metric
-
AppMonitor
-
Canary
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of this SLO.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#request_based_sli ⇒ Types::RequestBasedServiceLevelIndicator
A structure containing information about the performance metric that this SLO monitors, if this is a request-based SLO.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |
#sli ⇒ Types::ServiceLevelIndicator
A structure containing information about the performance metric that this SLO monitors, if this is a period-based SLO.
3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3395 class ServiceLevelObjective < Struct.new( :arn, :name, :description, :created_time, :last_updated_time, :sli, :request_based_sli, :evaluation_type, :goal, :burn_rate_configurations, :metric_source_type, :auto_investigation_enabled) SENSITIVE = [] include Aws::Structure end |