Class: Aws::ApplicationSignals::Types::ServiceLevelObjectiveSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

A structure that contains information about one service level objective (SLO) created in Application Signals.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of this service level objective.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#created_timeTime

The date and time that this service level objective was created. It is expressed as the number of milliseconds since Jan 1, 1970 00:00:00 UTC.

Returns:

  • (Time)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#dependency_configTypes::DependencyConfig

Identifies the dependency using the ‘DependencyKeyAttributes` and `DependencyOperationName`.



3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_typeString

Displays whether this is a period-based SLO or a request-based SLO.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#key_attributesHash<String,String>

This is a string-to-string map. It can include the following fields.

  • ‘Type` designates the type of object this service level objective is for.

  • ‘ResourceType` specifies the type of the resource. This field is used only when the value of the `Type` field is `Resource` or `AWS::Resource`.

  • ‘Name` specifies the name of the object. This is used only if the value of the `Type` field is `Service`, `RemoteService`, or `AWS::Service`.

  • ‘Identifier` identifies the resource objects of this resource. This is used only if the value of the `Type` field is `Resource` or `AWS::Resource`.

  • ‘Environment` specifies the location where this object is hosted, or what it belongs to.

Returns:

  • (Hash<String,String>)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#metric_sourceTypes::MetricSource

Identifies the metric source for SLOs on resources other than Application Signals services.

Returns:



3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#metric_source_typeString

Displays the SLI metric source type for this SLO. Supported types are:

  • Service operation

  • Service dependency

  • Service

  • CloudWatch metric

  • AppMonitor

  • Canary

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the service level objective.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end

#operation_nameString

If this service level objective is specific to a single operation, this field displays the name of that operation.

Returns:

  • (String)


3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3542

class ServiceLevelObjectiveSummary < Struct.new(
  :arn,
  :name,
  :key_attributes,
  :operation_name,
  :dependency_config,
  :created_time,
  :evaluation_type,
  :metric_source_type,
  :metric_source)
  SENSITIVE = []
  include Aws::Structure
end