Class: Aws::ApplicationSignals::Types::ServiceOperationEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::ServiceOperationEntity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
A structure that contains identifying information for a service operation entity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_type ⇒ String
The type of metric associated with this service operation.
-
#operation ⇒ String
The name of the operation.
-
#service ⇒ Types::ServiceEntity
The service entity that contains this operation.
Instance Attribute Details
#metric_type ⇒ String
The type of metric associated with this service operation.
3597 3598 3599 3600 3601 3602 3603 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3597 class ServiceOperationEntity < Struct.new( :service, :operation, :metric_type) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ String
The name of the operation.
3597 3598 3599 3600 3601 3602 3603 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3597 class ServiceOperationEntity < Struct.new( :service, :operation, :metric_type) SENSITIVE = [] include Aws::Structure end |
#service ⇒ Types::ServiceEntity
The service entity that contains this operation.
3597 3598 3599 3600 3601 3602 3603 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3597 class ServiceOperationEntity < Struct.new( :service, :operation, :metric_type) SENSITIVE = [] include Aws::Structure end |