Class: Aws::ApplicationSignals::Types::ServiceState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

A structure that contains information about the current state of a service, including its latest change events such as deployments and other state-changing activities.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_filtersArray<Types::AttributeFilter>

The attribute filters that were applied when retrieving this service state information.

Returns:



3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3640

class ServiceState < Struct.new(
  :attribute_filters,
  :service,
  :latest_change_events)
  SENSITIVE = []
  include Aws::Structure
end

#latest_change_eventsArray<Types::ChangeEvent>

An array containing the most recent change events for this service, such as deployments, with information about when they occurred and who initiated them.

Returns:



3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3640

class ServiceState < Struct.new(
  :attribute_filters,
  :service,
  :latest_change_events)
  SENSITIVE = []
  include Aws::Structure
end

#serviceHash<String,String>

The key attributes that identify this service, including Type, Name, and Environment information.

Returns:

  • (Hash<String,String>)


3640
3641
3642
3643
3644
3645
3646
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3640

class ServiceState < Struct.new(
  :attribute_filters,
  :service,
  :latest_change_events)
  SENSITIVE = []
  include Aws::Structure
end