Class: Aws::ApplicationSignals::Types::UnprocessedStatusEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

A status event that could not be processed by the service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_reasonString

The reason why this status event could not be processed, such as throttling or validation errors.

Returns:

  • (String)


5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067

class UnprocessedStatusEvent < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location_hash,
  :status,
  :time,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#instrumentation_typeString

The type of instrumentation configuration for the unprocessed status event.

Returns:

  • (String)


5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067

class UnprocessedStatusEvent < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location_hash,
  :status,
  :time,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#location_hashString

The stable hash of the instrumentation location for the unprocessed event.

Returns:

  • (String)


5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067

class UnprocessedStatusEvent < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location_hash,
  :status,
  :time,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#signal_typeString

The telemetry signal type for the unprocessed status event.

Returns:

  • (String)


5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067

class UnprocessedStatusEvent < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location_hash,
  :status,
  :time,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status that failed to be processed.

Returns:

  • (String)


5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067

class UnprocessedStatusEvent < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location_hash,
  :status,
  :time,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#timeTime

The timestamp of the status event that failed to be processed.

Returns:

  • (Time)


5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067

class UnprocessedStatusEvent < Struct.new(
  :instrumentation_type,
  :signal_type,
  :location_hash,
  :status,
  :time,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end