Module: Aws::ApplicationSignals::Types
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AttributeFilter, AuditFinding, AuditTarget, AuditTargetEntity, AuditorResult, BatchDeleteByResourceArns, BatchDeleteDeletionTarget, BatchDeleteError, BatchDeleteInstrumentationConfigurationsRequest, BatchDeleteInstrumentationConfigurationsResponse, BatchDeleteScope, BatchDeleteSuccessfulDeletion, BatchGetServiceLevelObjectiveBudgetReportInput, BatchGetServiceLevelObjectiveBudgetReportOutput, BatchUpdateExclusionWindowsError, BatchUpdateExclusionWindowsInput, BatchUpdateExclusionWindowsOutput, BurnRateConfiguration, CalendarInterval, CanaryEntity, CaptureConfiguration, CaptureLimitsConfig, ChangeEvent, CodeCaptureConfiguration, CodeLocation, CompositeSliComponent, CompositeSliConfig, ConflictException, CreateInstrumentationConfigurationRequest, CreateInstrumentationConfigurationResponse, CreateServiceLevelObjectiveInput, CreateServiceLevelObjectiveOutput, DeleteGroupingConfigurationOutput, DeleteInstrumentationConfigurationRequest, DeleteInstrumentationConfigurationResponse, DeleteServiceLevelObjectiveInput, DeleteServiceLevelObjectiveOutput, DependencyConfig, DependencyGraph, Dimension, Edge, ExclusionWindow, GetInstrumentationConfigurationRequest, GetInstrumentationConfigurationResponse, GetInstrumentationConfigurationStatusRequest, GetInstrumentationConfigurationStatusResponse, GetServiceInput, GetServiceLevelObjectiveInput, GetServiceLevelObjectiveOutput, GetServiceOutput, Goal, GroupingAttributeDefinition, GroupingConfiguration, InstrumentationConfiguration, InstrumentationConfigurationStatusReport, InstrumentationConfigurationWithoutServiceEnv, InstrumentationConfigurationsPage, InstrumentationStatusEvent, Interval, ListAuditFindingsInput, ListAuditFindingsOutput, ListEntityEventsInput, ListEntityEventsOutput, ListGroupingAttributeDefinitionsInput, ListGroupingAttributeDefinitionsOutput, ListInstrumentationConfigurationsRequest, ListServiceDependenciesInput, ListServiceDependenciesOutput, ListServiceDependentsInput, ListServiceDependentsOutput, ListServiceLevelObjectiveExclusionWindowsInput, ListServiceLevelObjectiveExclusionWindowsOutput, ListServiceLevelObjectivesInput, ListServiceLevelObjectivesOutput, ListServiceOperationsInput, ListServiceOperationsOutput, ListServiceStatesInput, ListServiceStatesOutput, ListServicesInput, ListServicesOutput, ListTagsForResourceRequest, ListTagsForResourceResponse, Location, LocationIdentifier, Metric, MetricDataQuery, MetricGraph, MetricReference, MetricSource, MetricStat, MonitoredRequestCountMetricDataQueries, Node, PutGroupingConfigurationInput, PutGroupingConfigurationOutput, RecurrenceRule, ReportInstrumentationConfigurationStatusRequest, ReportInstrumentationConfigurationStatusResponse, RequestBasedServiceLevelIndicator, RequestBasedServiceLevelIndicatorConfig, RequestBasedServiceLevelIndicatorMetric, RequestBasedServiceLevelIndicatorMetricConfig, ResourceNotFoundException, RollingInterval, SelectionConfig, Service, ServiceDependency, ServiceDependent, ServiceEntity, ServiceGroup, ServiceLevelIndicator, ServiceLevelIndicatorConfig, ServiceLevelIndicatorMetric, ServiceLevelIndicatorMetricConfig, ServiceLevelObjective, ServiceLevelObjectiveBudgetReport, ServiceLevelObjectiveBudgetReportError, ServiceLevelObjectiveEntity, ServiceLevelObjectiveSummary, ServiceOperation, ServiceOperationEntity, ServiceQuotaExceededException, ServiceState, ServiceSummary, StartDiscoveryInput, StartDiscoveryOutput, Tag, TagResourceRequest, TagResourceResponse, ThrottlingException, UnprocessedStatusEvent, UntagResourceRequest, UntagResourceResponse, UpdateServiceLevelObjectiveInput, UpdateServiceLevelObjectiveOutput, ValidationException, Window
Instance Attribute Summary collapse
-
#bad_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count “bad requests” to determine the percentage of successful requests for this request-based SLO, specify the metric to use as “bad requests” in this structure.
-
#calendar_interval ⇒ Types::CalendarInterval
If the interval is a calendar interval, this structure contains the interval specifications.
-
#canary ⇒ Types::CanaryEntity
Canary entity information when the audit target is a CloudWatch Synthetics canary.
-
#code_capture ⇒ Types::CodeCaptureConfiguration
Capture settings for code-level instrumentation, including arguments, return values, stack traces, local variables, and safety limits.
-
#code_location ⇒ Types::CodeLocation
The full code location specification (will be hashed internally).
-
#good_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count “good requests” to determine the percentage of successful requests for this request-based SLO, specify the metric to use as “good requests” in this structure.
-
#location_hash ⇒ String
The pre-computed location hash (16-character hex string).
-
#operation_name ⇒ String
The name of the operation to include in the composite SLI.
-
#resource_arns ⇒ Types::BatchDeleteByResourceArns
Delete specific configurations by ARN list.
-
#rolling_interval ⇒ Types::RollingInterval
If the interval is a rolling interval, this structure contains the interval specifications.
-
#scope ⇒ Types::BatchDeleteScope
Delete all configurations matching the specified scope.
-
#service ⇒ Types::ServiceEntity
Service entity information when the audit target is a service.
-
#service_operation ⇒ Types::ServiceOperationEntity
Service operation entity information when the audit target is a specific service operation.
-
#slo ⇒ Types::ServiceLevelObjectiveEntity
SLO entity information when the audit target is a service level objective.
Instance Attribute Details
#bad_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count “bad requests” to determine the percentage of successful requests for this request-based SLO, specify the metric to use as “bad requests” in this structure.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3417 class MonitoredRequestCountMetricDataQueries < Struct.new( :good_count_metric, :bad_count_metric, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GoodCountMetric < MonitoredRequestCountMetricDataQueries; end class BadCountMetric < MonitoredRequestCountMetricDataQueries; end class Unknown < MonitoredRequestCountMetricDataQueries; end end |
#calendar_interval ⇒ Types::CalendarInterval
If the interval is a calendar interval, this structure contains the interval specifications.
2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2001 class Interval < Struct.new( :rolling_interval, :calendar_interval, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RollingInterval < Interval; end class CalendarInterval < Interval; end class Unknown < Interval; end end |
#canary ⇒ Types::CanaryEntity
Canary entity information when the audit target is a CloudWatch Synthetics canary.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 148 class AuditTargetEntity < Struct.new( :service, :slo, :service_operation, :canary, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Service < AuditTargetEntity; end class Slo < AuditTargetEntity; end class ServiceOperation < AuditTargetEntity; end class Canary < AuditTargetEntity; end class Unknown < AuditTargetEntity; end end |
#code_capture ⇒ Types::CodeCaptureConfiguration
Capture settings for code-level instrumentation, including arguments, return values, stack traces, local variables, and safety limits.
566 567 568 569 570 571 572 573 574 575 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 566 class CaptureConfiguration < Struct.new( :code_capture, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CodeCapture < CaptureConfiguration; end class Unknown < CaptureConfiguration; end end |
#code_location ⇒ Types::CodeLocation
The full code location specification (will be hashed internally)
3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3047 class Location < Struct.new( :code_location, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CodeLocation < Location; end class Unknown < Location; end end |
#good_count_metric ⇒ Array<Types::MetricDataQuery>
If you want to count “good requests” to determine the percentage of successful requests for this request-based SLO, specify the metric to use as “good requests” in this structure.
3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3417 class MonitoredRequestCountMetricDataQueries < Struct.new( :good_count_metric, :bad_count_metric, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class GoodCountMetric < MonitoredRequestCountMetricDataQueries; end class BadCountMetric < MonitoredRequestCountMetricDataQueries; end class Unknown < MonitoredRequestCountMetricDataQueries; end end |
#location_hash ⇒ String
The pre-computed location hash (16-character hex string)
3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3074 class LocationIdentifier < Struct.new( :code_location, :location_hash, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CodeLocation < LocationIdentifier; end class LocationHash < LocationIdentifier; end class Unknown < LocationIdentifier; end end |
#operation_name ⇒ String
The name of the operation to include in the composite SLI.
823 824 825 826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 823 class CompositeSliComponent < Struct.new( :operation_name, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OperationName < CompositeSliComponent; end class Unknown < CompositeSliComponent; end end |
#resource_arns ⇒ Types::BatchDeleteByResourceArns
Delete specific configurations by ARN list.
233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 233 class BatchDeleteDeletionTarget < Struct.new( :scope, :resource_arns, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Scope < BatchDeleteDeletionTarget; end class ResourceArns < BatchDeleteDeletionTarget; end class Unknown < BatchDeleteDeletionTarget; end end |
#rolling_interval ⇒ Types::RollingInterval
If the interval is a rolling interval, this structure contains the interval specifications.
2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2001 class Interval < Struct.new( :rolling_interval, :calendar_interval, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class RollingInterval < Interval; end class CalendarInterval < Interval; end class Unknown < Interval; end end |
#scope ⇒ Types::BatchDeleteScope
Delete all configurations matching the specified scope.
233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 233 class BatchDeleteDeletionTarget < Struct.new( :scope, :resource_arns, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Scope < BatchDeleteDeletionTarget; end class ResourceArns < BatchDeleteDeletionTarget; end class Unknown < BatchDeleteDeletionTarget; end end |
#service ⇒ Types::ServiceEntity
Service entity information when the audit target is a service.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 148 class AuditTargetEntity < Struct.new( :service, :slo, :service_operation, :canary, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Service < AuditTargetEntity; end class Slo < AuditTargetEntity; end class ServiceOperation < AuditTargetEntity; end class Canary < AuditTargetEntity; end class Unknown < AuditTargetEntity; end end |
#service_operation ⇒ Types::ServiceOperationEntity
Service operation entity information when the audit target is a specific service operation.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 148 class AuditTargetEntity < Struct.new( :service, :slo, :service_operation, :canary, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Service < AuditTargetEntity; end class Slo < AuditTargetEntity; end class ServiceOperation < AuditTargetEntity; end class Canary < AuditTargetEntity; end class Unknown < AuditTargetEntity; end end |
#slo ⇒ Types::ServiceLevelObjectiveEntity
SLO entity information when the audit target is a service level objective.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 148 class AuditTargetEntity < Struct.new( :service, :slo, :service_operation, :canary, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Service < AuditTargetEntity; end class Slo < AuditTargetEntity; end class ServiceOperation < AuditTargetEntity; end class Canary < AuditTargetEntity; end class Unknown < AuditTargetEntity; end end |