Class: Aws::ApplicationSignals::Types::CaptureLimitsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::CaptureLimitsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Guardrails that prevent instrumentation from impacting application performance by limiting how much data is captured.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_collection_depth ⇒ Integer
The maximum nesting depth to traverse inside collections.
-
#max_collection_width ⇒ Integer
The maximum number of items to capture from any collection to prevent large payloads.
-
#max_fields_per_object ⇒ Integer
The maximum number of fields to capture for any object.
-
#max_hits ⇒ Integer
The maximum number of times the instrumentation point can be hit before it is automatically disabled.
-
#max_object_depth ⇒ Integer
The maximum depth for nested object traversal when capturing structured data.
-
#max_stack_frames ⇒ Integer
The maximum number of stack frames to capture in stack traces.
-
#max_stack_trace_size ⇒ Integer
The maximum total size, in bytes, of a captured stack trace.
-
#max_string_length ⇒ Integer
The maximum length of captured string values in characters.
Instance Attribute Details
#max_collection_depth ⇒ Integer
The maximum nesting depth to traverse inside collections. Defaults to 3.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |
#max_collection_width ⇒ Integer
The maximum number of items to capture from any collection to prevent large payloads. Defaults to 10.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |
#max_fields_per_object ⇒ Integer
The maximum number of fields to capture for any object. Defaults to 10.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |
#max_hits ⇒ Integer
The maximum number of times the instrumentation point can be hit before it is automatically disabled. Defaults to 100.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |
#max_object_depth ⇒ Integer
The maximum depth for nested object traversal when capturing structured data. Defaults to 3.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |
#max_stack_frames ⇒ Integer
The maximum number of stack frames to capture in stack traces. Defaults to 2.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |
#max_stack_trace_size ⇒ Integer
The maximum total size, in bytes, of a captured stack trace. Defaults to 1000.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |
#max_string_length ⇒ Integer
The maximum length of captured string values in characters. Strings longer than this are truncated. Defaults to 128.
622 623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 622 class CaptureLimitsConfig < Struct.new( :max_hits, :max_string_length, :max_collection_width, :max_collection_depth, :max_stack_frames, :max_stack_trace_size, :max_object_depth, :max_fields_per_object) SENSITIVE = [] include Aws::Structure end |