Class: Aws::ApplicationSignals::Types::CodeLocation
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::CodeLocation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Identifies a code location to instrument, including the programming language, code unit, class, method, file path, and optional line number.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#class_name ⇒ String
The class or type name that contains the method.
-
#code_unit ⇒ String
The package, module, or namespace that contains the target code, for example ‘com.amazon.payment` or `payment_service`.
-
#file_path ⇒ String
The source file path relative to the project or source root, such as ‘src/payment/PaymentProcessor.java` or `src/payment/PaymentProcessor.py`.
-
#language ⇒ String
The programming language for this instrumentation point, such as Java, Python, or JavaScript.
-
#line_number ⇒ Integer
The line number to instrument.
-
#method_name ⇒ String
The method or function name to instrument, such as ‘validateCreditCard` or `__init__`.
Instance Attribute Details
#class_name ⇒ String
The class or type name that contains the method. This is required for Java and optional for Python module-level functions.
798 799 800 801 802 803 804 805 806 807 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798 class CodeLocation < Struct.new( :language, :code_unit, :class_name, :method_name, :file_path, :line_number) SENSITIVE = [] include Aws::Structure end |
#code_unit ⇒ String
The package, module, or namespace that contains the target code, for example ‘com.amazon.payment` or `payment_service`.
798 799 800 801 802 803 804 805 806 807 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798 class CodeLocation < Struct.new( :language, :code_unit, :class_name, :method_name, :file_path, :line_number) SENSITIVE = [] include Aws::Structure end |
#file_path ⇒ String
The source file path relative to the project or source root, such as ‘src/payment/PaymentProcessor.java` or `src/payment/PaymentProcessor.py`.
798 799 800 801 802 803 804 805 806 807 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798 class CodeLocation < Struct.new( :language, :code_unit, :class_name, :method_name, :file_path, :line_number) SENSITIVE = [] include Aws::Structure end |
#language ⇒ String
The programming language for this instrumentation point, such as Java, Python, or JavaScript.
798 799 800 801 802 803 804 805 806 807 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798 class CodeLocation < Struct.new( :language, :code_unit, :class_name, :method_name, :file_path, :line_number) SENSITIVE = [] include Aws::Structure end |
#line_number ⇒ Integer
The line number to instrument. Provide this to disambiguate overloaded methods and to target a specific line when needed.
798 799 800 801 802 803 804 805 806 807 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798 class CodeLocation < Struct.new( :language, :code_unit, :class_name, :method_name, :file_path, :line_number) SENSITIVE = [] include Aws::Structure end |
#method_name ⇒ String
The method or function name to instrument, such as ‘validateCreditCard` or `__init__`.
798 799 800 801 802 803 804 805 806 807 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 798 class CodeLocation < Struct.new( :language, :code_unit, :class_name, :method_name, :file_path, :line_number) SENSITIVE = [] include Aws::Structure end |