Class: Aws::ApplicationSignals::Types::CompositeSliComponent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::CompositeSliComponent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Note:
CompositeSliComponent is a union - when making an API calls you must set exactly one of the members.
Note:
CompositeSliComponent is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CompositeSliComponent corresponding to the set member.
Identifies a single operation to include in a composite SLI for a service-level SLO. Used as an element of the ‘Components` list in `CompositeSliConfig`.
Direct Known Subclasses
Defined Under Namespace
Classes: OperationName, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation_name ⇒ String
The name of the operation to include in the composite SLI.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#operation_name ⇒ String
The name of the operation to include in the composite SLI.
489 490 491 492 493 494 495 496 497 498 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 489 class CompositeSliComponent < Struct.new( :operation_name, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OperationName < CompositeSliComponent; end class Unknown < CompositeSliComponent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
489 490 491 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 489 def unknown @unknown end |