Class: Aws::ApplicationSignals::Types::CreateInstrumentationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::CreateInstrumentationConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_filters ⇒ Array<Hash<String,String>>
Client-side filters that target specific instances.
-
#capture_configuration ⇒ Types::CaptureConfiguration
Specifies what to capture when the instrumentation point is hit.
-
#description ⇒ String
An optional short description (up to 50 characters) that explains the purpose of this instrumentation.
-
#environment ⇒ String
The environment that the service is running in, such as ‘eks:cluster-prod/namespace` or `ec2:production`.
-
#expires_at ⇒ Time
For BREAKPOINT: optional, defaults to 24 hours, must be between 5 min and 24 hours.
-
#instrumentation_type ⇒ String
Type of instrumentation: BREAKPOINT (temporary) or PROBE (permanent).
-
#location ⇒ Types::Location
The location where instrumentation should be applied.
-
#service ⇒ String
The name of the service to instrument.
-
#signal_type ⇒ String
The telemetry signal type to emit for this instrumentation.
-
#tags ⇒ Array<Types::Tag>
An optional list of key-value pairs to associate with the instrumentation configuration.
Instance Attribute Details
#attribute_filters ⇒ Array<Hash<String,String>>
Client-side filters that target specific instances. Each object in the array is AND-matched on its keys, and multiple objects are OR-matched to decide where to apply the instrumentation.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#capture_configuration ⇒ Types::CaptureConfiguration
Specifies what to capture when the instrumentation point is hit. Specify ‘CodeCapture` for code-level capture settings.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional short description (up to 50 characters) that explains the purpose of this instrumentation.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ String
The environment that the service is running in, such as ‘eks:cluster-prod/namespace` or `ec2:production`.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#expires_at ⇒ Time
For BREAKPOINT: optional, defaults to 24 hours, must be between 5 min and 24 hours. For PROBE: not supported. PROBE configurations are permanent and persist until explicitly deleted.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#instrumentation_type ⇒ String
Type of instrumentation: BREAKPOINT (temporary) or PROBE (permanent)
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::Location
The location where instrumentation should be applied. Specify a ‘CodeLocation` for code-level instrumentation.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The name of the service to instrument. This should match the ‘service.name` resource attribute reported by the application.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
The telemetry signal type to emit for this instrumentation. The supported value is ‘SNAPSHOT`.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An optional list of key-value pairs to associate with the instrumentation configuration. Tags can help you organize and categorize your resources.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 928 class CreateInstrumentationConfigurationRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :description, :expires_at, :attribute_filters, :capture_configuration, :tags) SENSITIVE = [] include Aws::Structure end |