Class: Aws::ApplicationSignals::Types::CreateInstrumentationConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::CreateInstrumentationConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN for the created instrumentation configuration.
-
#attribute_filters ⇒ Array<Hash<String,String>>
The attribute filters returned with the configuration so SDKs can perform client-side targeting.
-
#capture_configuration ⇒ Types::CaptureConfiguration
The capture settings that were stored for this instrumentation configuration.
-
#created_at ⇒ Time
The server-generated creation timestamp for this instrumentation configuration.
-
#description ⇒ String
The optional description that was stored with the instrumentation configuration.
-
#environment ⇒ String
The environment for the instrumentation configuration, echoed from the request.
-
#expires_at ⇒ Time
The timestamp after which this configuration is no longer served to clients.
-
#instrumentation_type ⇒ String
The type of instrumentation that was created, echoed from the request.
-
#location ⇒ Types::Location
The location where instrumentation is applied, echoed from the request.
-
#location_hash ⇒ String
A stable hash computed from the location that uniquely identifies this instrumentation point within the service, environment, and signal type.
-
#service ⇒ String
The service name for the instrumentation configuration, echoed from the request.
-
#signal_type ⇒ String
The telemetry signal type for the instrumentation configuration, echoed from the request.
Instance Attribute Details
#arn ⇒ String
ARN for the created instrumentation configuration
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#attribute_filters ⇒ Array<Hash<String,String>>
The attribute filters returned with the configuration so SDKs can perform client-side targeting.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#capture_configuration ⇒ Types::CaptureConfiguration
The capture settings that were stored for this instrumentation configuration.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The server-generated creation timestamp for this instrumentation configuration.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The optional description that was stored with the instrumentation configuration.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ String
The environment for the instrumentation configuration, echoed from the request.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#expires_at ⇒ Time
The timestamp after which this configuration is no longer served to clients. Present only for ‘BREAKPOINT` configurations; `PROBE` configurations do not expire.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#instrumentation_type ⇒ String
The type of instrumentation that was created, echoed from the request.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::Location
The location where instrumentation is applied, echoed from the request.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#location_hash ⇒ String
A stable hash computed from the location that uniquely identifies this instrumentation point within the service, environment, and signal type.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service name for the instrumentation configuration, echoed from the request.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
The telemetry signal type for the instrumentation configuration, echoed from the request.
1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1006 class CreateInstrumentationConfigurationResponse < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |