Class: Aws::ApplicationSignals::Types::GetInstrumentationConfigurationStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::GetInstrumentationConfigurationStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The end of the time range to retrieve status events for.
-
#environment ⇒ String
Environment name for the instrumentation configuration.
-
#instrumentation_type ⇒ String
Type of instrumentation configuration (BREAKPOINT or PROBE).
-
#location_identifier ⇒ Types::LocationIdentifier
Location identifier - either full code location or a pre-computed hash.
-
#max_results ⇒ Integer
The maximum number of status events to return in one call.
-
#next_token ⇒ String
Use the token returned by a previous call to retrieve the next page of status events.
-
#service ⇒ String
Service name for the instrumentation configuration.
-
#signal_type ⇒ String
Signal type for the instrumentation configuration.
-
#start_time ⇒ Time
The start of the time range to retrieve status events for.
-
#status ⇒ String
The single status to query for.
Instance Attribute Details
#end_time ⇒ Time
The end of the time range to retrieve status events for. ‘StartTime` and `EndTime` must both be provided together or both be omitted. When both are omitted, the time range defaults to the last hour.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ String
Environment name for the instrumentation configuration.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#instrumentation_type ⇒ String
Type of instrumentation configuration (BREAKPOINT or PROBE). Required to identify the configuration to retrieve.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#location_identifier ⇒ Types::LocationIdentifier
Location identifier - either full code location or a pre-computed hash.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of status events to return in one call. The default is 60.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Use the token returned by a previous call to retrieve the next page of status events.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
Service name for the instrumentation configuration.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
Signal type for the instrumentation configuration.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start of the time range to retrieve status events for. ‘StartTime` and `EndTime` must both be provided together or both be omitted. When both are omitted, the time range defaults to the last hour.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The single status to query for. If omitted, only ‘ACTIVE` status events are returned.
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1445 class GetInstrumentationConfigurationStatusRequest < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location_identifier, :status, :start_time, :end_time, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |