Class: Aws::ApplicationSignals::Types::GetInstrumentationConfigurationStatusResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::GetInstrumentationConfigurationStatusResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment ⇒ String
The environment echoed from the request.
-
#events ⇒ Array<Types::InstrumentationStatusEvent>
The list of status events within the requested time window, sorted with the most recent first.
-
#location ⇒ Types::Location
The code location echoed from the request.
-
#next_token ⇒ String
Pagination token to continue retrieving status events.
-
#service ⇒ String
The service name echoed from the request.
-
#signal_type ⇒ String
The telemetry signal type echoed from the request.
-
#status ⇒ String
The status that was queried.
Instance Attribute Details
#environment ⇒ String
The environment echoed from the request.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492 class GetInstrumentationConfigurationStatusResponse < Struct.new( :service, :environment, :signal_type, :location, :status, :events, :next_token) SENSITIVE = [] include Aws::Structure end |
#events ⇒ Array<Types::InstrumentationStatusEvent>
The list of status events within the requested time window, sorted with the most recent first. Error events include an error cause.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492 class GetInstrumentationConfigurationStatusResponse < Struct.new( :service, :environment, :signal_type, :location, :status, :events, :next_token) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::Location
The code location echoed from the request.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492 class GetInstrumentationConfigurationStatusResponse < Struct.new( :service, :environment, :signal_type, :location, :status, :events, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token to continue retrieving status events.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492 class GetInstrumentationConfigurationStatusResponse < Struct.new( :service, :environment, :signal_type, :location, :status, :events, :next_token) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service name echoed from the request.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492 class GetInstrumentationConfigurationStatusResponse < Struct.new( :service, :environment, :signal_type, :location, :status, :events, :next_token) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
The telemetry signal type echoed from the request.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492 class GetInstrumentationConfigurationStatusResponse < Struct.new( :service, :environment, :signal_type, :location, :status, :events, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status that was queried. If not specified in the request, this is ‘ACTIVE`.
1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1492 class GetInstrumentationConfigurationStatusResponse < Struct.new( :service, :environment, :signal_type, :location, :status, :events, :next_token) SENSITIVE = [] include Aws::Structure end |