Class: Aws::ApplicationSignals::Types::InstrumentationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::InstrumentationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
The full instrumentation configuration, including the instrumentation type, service, environment, signal type, location details, stable location hash, capture settings, filters, expiration, creation time, and ARN.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN for the instrumentation configuration.
-
#attribute_filters ⇒ Array<Hash<String,String>>
Client-side filters that determine which instances apply this instrumentation.
-
#capture_configuration ⇒ Types::CaptureConfiguration
The capture settings for this instrumentation configuration.
-
#created_at ⇒ Time
The timestamp when this instrumentation configuration was created.
-
#description ⇒ String
An optional short description of the instrumentation configuration.
-
#environment ⇒ String
The environment where the service is running.
-
#expires_at ⇒ Time
The timestamp when this configuration expires.
-
#instrumentation_type ⇒ String
The type of instrumentation for this configuration.
-
#location ⇒ Types::Location
The location where this instrumentation is applied.
-
#location_hash ⇒ String
The stable hash derived from the location that uniquely identifies this instrumentation point within the service and environment.
-
#service ⇒ String
The service that this instrumentation configuration targets.
-
#signal_type ⇒ String
The telemetry signal type for this instrumentation configuration.
Instance Attribute Details
#arn ⇒ String
ARN for the instrumentation configuration
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#attribute_filters ⇒ Array<Hash<String,String>>
Client-side filters that determine which instances apply this instrumentation.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#capture_configuration ⇒ Types::CaptureConfiguration
The capture settings for this instrumentation configuration.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when this instrumentation configuration was created.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional short description of the instrumentation configuration.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ String
The environment where the service is running.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#expires_at ⇒ Time
The timestamp when this configuration expires.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#instrumentation_type ⇒ String
The type of instrumentation for this configuration.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::Location
The location where this instrumentation is applied.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#location_hash ⇒ String
The stable hash derived from the location that uniquely identifies this instrumentation point within the service and environment.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service that this instrumentation configuration targets.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
The telemetry signal type for this instrumentation configuration.
1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1790 class InstrumentationConfiguration < Struct.new( :instrumentation_type, :service, :environment, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |