Class: Aws::ApplicationSignals::Types::InstrumentationConfigurationWithoutServiceEnv
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::InstrumentationConfigurationWithoutServiceEnv
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
An instrumentation configuration that omits service and environment because they are provided at a higher level, such as in a list response.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN for the instrumentation configuration.
-
#attribute_filters ⇒ Array<Hash<String,String>>
Client-side filters that determine which instances apply this instrumentation.
-
#capture_configuration ⇒ Types::CaptureConfiguration
The capture settings for this instrumentation configuration.
-
#created_at ⇒ Time
The timestamp when this instrumentation configuration was created.
-
#description ⇒ String
An optional short description of the instrumentation configuration.
-
#expires_at ⇒ Time
The timestamp when this configuration expires.
-
#instrumentation_type ⇒ String
The type of instrumentation for this configuration.
-
#location ⇒ Types::Location
The location where this instrumentation is applied.
-
#location_hash ⇒ String
The stable hash derived from the location that identifies this instrumentation point.
-
#signal_type ⇒ String
The telemetry signal type for this instrumentation configuration.
Instance Attribute Details
#arn ⇒ String
ARN for the instrumentation configuration
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#attribute_filters ⇒ Array<Hash<String,String>>
Client-side filters that determine which instances apply this instrumentation.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#capture_configuration ⇒ Types::CaptureConfiguration
The capture settings for this instrumentation configuration.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when this instrumentation configuration was created.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
An optional short description of the instrumentation configuration.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#expires_at ⇒ Time
The timestamp when this configuration expires.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#instrumentation_type ⇒ String
The type of instrumentation for this configuration.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::Location
The location where this instrumentation is applied.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#location_hash ⇒ String
The stable hash derived from the location that identifies this instrumentation point.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
The telemetry signal type for this instrumentation configuration.
1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1898 class InstrumentationConfigurationWithoutServiceEnv < Struct.new( :instrumentation_type, :signal_type, :location, :location_hash, :description, :expires_at, :attribute_filters, :capture_configuration, :created_at, :arn) SENSITIVE = [] include Aws::Structure end |