Class: Aws::ApplicationSignals::Types::InstrumentationConfigurationsPage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::InstrumentationConfigurationsPage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#changed ⇒ Boolean
Indicates whether there are configuration changes since the provided ‘SyncedAt` timestamp.
-
#environment ⇒ String
The environment associated with the returned configurations.
-
#latest_configurations ⇒ Array<Types::InstrumentationConfigurationWithoutServiceEnv>
The current set of active instrumentation configurations for the service and environment.
-
#next_token ⇒ String
Pagination token to continue listing configurations when more results are available.
-
#service ⇒ String
The service name associated with the returned configurations.
-
#sync_interval ⇒ Integer
The suggested number of seconds to wait before the next sync request.
-
#synced_at ⇒ Time
The server timestamp to supply on the next sync call.
Instance Attribute Details
#changed ⇒ Boolean
Indicates whether there are configuration changes since the provided ‘SyncedAt` timestamp.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948 class InstrumentationConfigurationsPage < Struct.new( :service, :environment, :changed, :latest_configurations, :synced_at, :sync_interval, :next_token) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ String
The environment associated with the returned configurations.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948 class InstrumentationConfigurationsPage < Struct.new( :service, :environment, :changed, :latest_configurations, :synced_at, :sync_interval, :next_token) SENSITIVE = [] include Aws::Structure end |
#latest_configurations ⇒ Array<Types::InstrumentationConfigurationWithoutServiceEnv>
The current set of active instrumentation configurations for the service and environment. Items omit service and environment because they are provided in the request.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948 class InstrumentationConfigurationsPage < Struct.new( :service, :environment, :changed, :latest_configurations, :synced_at, :sync_interval, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token to continue listing configurations when more results are available.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948 class InstrumentationConfigurationsPage < Struct.new( :service, :environment, :changed, :latest_configurations, :synced_at, :sync_interval, :next_token) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The service name associated with the returned configurations.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948 class InstrumentationConfigurationsPage < Struct.new( :service, :environment, :changed, :latest_configurations, :synced_at, :sync_interval, :next_token) SENSITIVE = [] include Aws::Structure end |
#sync_interval ⇒ Integer
The suggested number of seconds to wait before the next sync request. This is at least 60 seconds to prevent excessive polling.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948 class InstrumentationConfigurationsPage < Struct.new( :service, :environment, :changed, :latest_configurations, :synced_at, :sync_interval, :next_token) SENSITIVE = [] include Aws::Structure end |
#synced_at ⇒ Time
The server timestamp to supply on the next sync call.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1948 class InstrumentationConfigurationsPage < Struct.new( :service, :environment, :changed, :latest_configurations, :synced_at, :sync_interval, :next_token) SENSITIVE = [] include Aws::Structure end |