Class: Aws::ApplicationSignals::Types::InstrumentationStatusEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::InstrumentationStatusEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
A status event for an instrumentation configuration returned by ‘GetInstrumentationConfigurationStatus`. Events include the timestamp and, for errors, an error cause.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_cause ⇒ String
The error cause when the status is ‘ERROR`.
-
#time ⇒ Time
The time when the status was reported, rounded to the nearest minute.
Instance Attribute Details
#error_cause ⇒ String
The error cause when the status is ‘ERROR`.
1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1975 class InstrumentationStatusEvent < Struct.new( :time, :error_cause) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Time
The time when the status was reported, rounded to the nearest minute.
1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 1975 class InstrumentationStatusEvent < Struct.new( :time, :error_cause) SENSITIVE = [] include Aws::Structure end |