Class: Aws::ApplicationSignals::Types::Node
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::Node
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
A structure that represents a node in a dependency graph, containing information about a service, resource, or other entity and its characteristics.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration ⇒ Float
The duration or processing time associated with this node, if applicable.
-
#key_attributes ⇒ Hash<String,String>
The key attributes that identify this node, including Type, Name, and Environment information.
-
#name ⇒ String
The name of the entity represented by this node.
-
#node_id ⇒ String
A unique identifier for this node within the dependency graph.
-
#operation ⇒ String
The operation associated with this node, if applicable.
-
#status ⇒ String
The status of the entity represented by this node.
-
#type ⇒ String
The type of entity represented by this node, such as ‘Service` or `Resource`.
Instance Attribute Details
#duration ⇒ Float
The duration or processing time associated with this node, if applicable.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375 class Node < Struct.new( :key_attributes, :name, :node_id, :operation, :type, :duration, :status) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
The key attributes that identify this node, including Type, Name, and Environment information.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375 class Node < Struct.new( :key_attributes, :name, :node_id, :operation, :type, :duration, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the entity represented by this node.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375 class Node < Struct.new( :key_attributes, :name, :node_id, :operation, :type, :duration, :status) SENSITIVE = [] include Aws::Structure end |
#node_id ⇒ String
A unique identifier for this node within the dependency graph.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375 class Node < Struct.new( :key_attributes, :name, :node_id, :operation, :type, :duration, :status) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ String
The operation associated with this node, if applicable.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375 class Node < Struct.new( :key_attributes, :name, :node_id, :operation, :type, :duration, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the entity represented by this node.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375 class Node < Struct.new( :key_attributes, :name, :node_id, :operation, :type, :duration, :status) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of entity represented by this node, such as ‘Service` or `Resource`.
2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2375 class Node < Struct.new( :key_attributes, :name, :node_id, :operation, :type, :duration, :status) SENSITIVE = [] include Aws::Structure end |