Class: Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure contains the information about the metric that is used for a request-based SLO.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the ‘DependencyKeyAttributes` and `DependencyOperationName`.
-
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to.
-
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
-
#metric_type ⇒ String
If the SLO monitors either the ‘LATENCY` or `AVAILABILITY` metric that Application Signals collects, this field displays which of those metrics is used.
-
#monitored_request_count_metric ⇒ Types::MonitoredRequestCountMetricDataQueries
This structure defines the metric that is used as the “good request” or “bad request” value for a request-based SLO.
-
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
-
#total_request_count_metric ⇒ Array<Types::MetricDataQuery>
This structure defines the metric that is used as the “total requests” number for a request-based SLO.
Instance Attribute Details
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the ‘DependencyKeyAttributes` and `DependencyOperationName`.
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2553 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to. It can include the following fields.
-
‘Type` designates the type of object that this SLO is related to.
-
‘ResourceType` specifies the type of the resource. This field is used only when the value of the `Type` field is `Resource` or `AWS::Resource`.
-
‘Name` specifies the name of the object. This is used only if the value of the `Type` field is `Service`, `RemoteService`, or `AWS::Service`.
-
‘Identifier` identifies the resource objects of this resource. This is used only if the value of the `Type` field is `Resource` or `AWS::Resource`.
-
‘Environment` specifies the location where this object is hosted, or what it belongs to.
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2553 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2553 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
If the SLO monitors either the ‘LATENCY` or `AVAILABILITY` metric that Application Signals collects, this field displays which of those metrics is used.
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2553 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#monitored_request_count_metric ⇒ Types::MonitoredRequestCountMetricDataQueries
This structure defines the metric that is used as the “good request” or “bad request” value for a request-based SLO. This value observed for the metric defined in ‘TotalRequestCountMetric` is divided by the number found for `MonitoredRequestCountMetric` to determine the percentage of successful requests that this SLO tracks.
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2553 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2553 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#total_request_count_metric ⇒ Array<Types::MetricDataQuery>
This structure defines the metric that is used as the “total requests” number for a request-based SLO. The number observed for this metric is divided by the number of “good requests” or “bad requests” that is observed for the metric defined in ‘MonitoredRequestCountMetric`.
2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 2553 class RequestBasedServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |