Class: Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorMetricConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::RequestBasedServiceLevelIndicatorMetricConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
Use this structure to specify the information for the metric that a period-based SLO will monitor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#composite_sli_config ⇒ Types::CompositeSliConfig
The composite SLI configuration for service-level SLOs that monitor multiple operations of a service.
-
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the
DependencyKeyAttributesandDependencyOperationName. -
#key_attributes ⇒ Hash<String,String>
If this SLO is related to a metric collected by Application Signals, you must use this field to specify which service the SLO metric is related to.
-
#metric_name ⇒ String
The name of the metric for SLOs on resources other than Application Signals services.
-
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
-
#metric_type ⇒ String
If the SLO is to monitor either the
LATENCYorAVAILABILITYmetric that Application Signals collects, use this field to specify which of those metrics is used. -
#monitored_request_count_metric ⇒ Types::MonitoredRequestCountMetricDataQueries
Use this structure to define the metric that you want to use as the "good request" or "bad request" value for a request-based SLO.
-
#operation_name ⇒ String
If the SLO is to monitor a specific operation of the service, use this field to specify the name of that operation.
-
#total_request_count_metric ⇒ Array<Types::MetricDataQuery>
Use this structure to define the metric that you want to use as the "total requests" number for a request-based SLO.
Instance Attribute Details
#composite_sli_config ⇒ Types::CompositeSliConfig
The composite SLI configuration for service-level SLOs that monitor multiple operations of a service.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the DependencyKeyAttributes and
DependencyOperationName.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
If this SLO is related to a metric collected by Application Signals,
you must use this field to specify which service the SLO metric is
related to. To do so, you must specify at least the Type, Name,
and Environment attributes.
This is a string-to-string map. It can include the following fields.
-
Typedesignates the type of object this is. -
ResourceTypespecifies the type of the resource. This field is used only when the value of theTypefield isResourceorAWS::Resource. -
Namespecifies the name of the object. This is used only if the value of theTypefield isService,RemoteService, orAWS::Service. -
Identifieridentifies the resource objects of this resource. This is used only if the value of theTypefield isResourceorAWS::Resource. -
Environmentspecifies the location where this object is hosted, or what it belongs to.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
The name of the metric for SLOs on resources other than Application Signals services.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
If the SLO is to monitor either the LATENCY or AVAILABILITY
metric that Application Signals collects, use this field to specify
which of those metrics is used.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#monitored_request_count_metric ⇒ Types::MonitoredRequestCountMetricDataQueries
Use this structure to define the metric that you want to use as the
"good request" or "bad request" value for a request-based SLO.
This value observed for the metric defined in
TotalRequestCountMetric will be divided by the number found for
MonitoredRequestCountMetric to determine the percentage of
successful requests that this SLO tracks.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#operation_name ⇒ String
If the SLO is to monitor a specific operation of the service, use this field to specify the name of that operation.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |
#total_request_count_metric ⇒ Array<Types::MetricDataQuery>
Use this structure to define the metric that you want to use as the
"total requests" number for a request-based SLO. This result will
be divided by the "good request" or "bad request" value defined
in MonitoredRequestCountMetric.
3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3789 class RequestBasedServiceLevelIndicatorMetricConfig < Struct.new( :key_attributes, :operation_name, :metric_type, :total_request_count_metric, :monitored_request_count_metric, :dependency_config, :metric_source, :metric_name, :composite_sli_config) SENSITIVE = [] include Aws::Structure end |