Class: Aws::ApplicationSignals::Types::ServiceLevelIndicatorConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::ServiceLevelIndicatorConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure specifies the information about the service and the performance metric that a period-based SLO is to monitor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the specified metric to the threshold.
-
#metric_threshold ⇒ Float
This parameter is used only when a request-based SLO tracks the
Latencymetric. -
#sli_metric_config ⇒ Types::ServiceLevelIndicatorMetricConfig
Use this structure to specify the metric to be used for the SLO.
Instance Attribute Details
#comparison_operator ⇒ String
The arithmetic operation to use when comparing the specified metric to the threshold.
This is not required if CreateRecommendedSlo is set to true.
4213 4214 4215 4216 4217 4218 4219 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4213 class ServiceLevelIndicatorConfig < Struct.new( :sli_metric_config, :metric_threshold, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#metric_threshold ⇒ Float
This parameter is used only when a request-based SLO tracks the
Latency metric. Specify the threshold value that the observed
Latency metric values are to be compared to.
This is not required if CreateRecommendedSlo is set to true.
4213 4214 4215 4216 4217 4218 4219 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4213 class ServiceLevelIndicatorConfig < Struct.new( :sli_metric_config, :metric_threshold, :comparison_operator) SENSITIVE = [] include Aws::Structure end |
#sli_metric_config ⇒ Types::ServiceLevelIndicatorMetricConfig
Use this structure to specify the metric to be used for the SLO.
4213 4214 4215 4216 4217 4218 4219 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4213 class ServiceLevelIndicatorConfig < Struct.new( :sli_metric_config, :metric_threshold, :comparison_operator) SENSITIVE = [] include Aws::Structure end |