Class: Aws::ApplicationSignals::Types::ServiceLevelIndicatorMetric
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::ServiceLevelIndicatorMetric
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
This structure contains the information about the metric that is used for a period-based SLO.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the ‘DependencyKeyAttributes` and `DependencyOperationName`.
-
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to.
-
#metric_data_queries ⇒ Array<Types::MetricDataQuery>
If this SLO monitors a CloudWatch metric or the result of a CloudWatch metric math expression, this structure includes the information about that metric or expression.
-
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
-
#metric_type ⇒ String
If the SLO monitors either the ‘LATENCY` or `AVAILABILITY` metric that Application Signals collects, this field displays which of those metrics is used.
-
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
Instance Attribute Details
#dependency_config ⇒ Types::DependencyConfig
Identifies the dependency using the ‘DependencyKeyAttributes` and `DependencyOperationName`.
3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3089 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#key_attributes ⇒ Hash<String,String>
This is a string-to-string map that contains information about the type of object that this SLO is related to. It can include the following fields.
-
‘Type` designates the type of object that this SLO is related to.
-
‘ResourceType` specifies the type of the resource. This field is used only when the value of the `Type` field is `Resource` or `AWS::Resource`.
-
‘Name` specifies the name of the object. This is used only if the value of the `Type` field is `Service`, `RemoteService`, or `AWS::Service`.
-
‘Identifier` identifies the resource objects of this resource. This is used only if the value of the `Type` field is `Resource` or `AWS::Resource`.
-
‘Environment` specifies the location where this object is hosted, or what it belongs to.
3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3089 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#metric_data_queries ⇒ Array<Types::MetricDataQuery>
If this SLO monitors a CloudWatch metric or the result of a CloudWatch metric math expression, this structure includes the information about that metric or expression.
3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3089 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#metric_source ⇒ Types::MetricSource
Identifies the metric source for SLOs on resources other than Application Signals services.
3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3089 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#metric_type ⇒ String
If the SLO monitors either the ‘LATENCY` or `AVAILABILITY` metric that Application Signals collects, this field displays which of those metrics is used.
3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3089 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |
#operation_name ⇒ String
If the SLO monitors a specific operation of the service, this field displays that operation name.
3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3089 class ServiceLevelIndicatorMetric < Struct.new( :key_attributes, :operation_name, :metric_type, :metric_data_queries, :dependency_config, :metric_source) SENSITIVE = [] include Aws::Structure end |