Class: Aws::ApplicationSignals::Types::ServiceLevelIndicatorMetricConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Use this structure to specify the information for the metric that a period-based SLO will monitor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dependency_configTypes::DependencyConfig

Identifies the dependency using the ‘DependencyKeyAttributes` and `DependencyOperationName`.



3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#key_attributesHash<String,String>

If this SLO is related to a metric collected by Application Signals, you must use this field to specify which service the SLO metric is related to. To do so, you must specify at least the ‘Type`, `Name`, and `Environment` attributes.

This is a string-to-string map. It can include the following fields.

  • ‘Type` designates the type of object this is.

  • ‘ResourceType` specifies the type of the resource. This field is used only when the value of the `Type` field is `Resource` or `AWS::Resource`.

  • ‘Name` specifies the name of the object. This is used only if the value of the `Type` field is `Service`, `RemoteService`, or `AWS::Service`.

  • ‘Identifier` identifies the resource objects of this resource. This is used only if the value of the `Type` field is `Resource` or `AWS::Resource`.

  • ‘Environment` specifies the location where this object is hosted, or what it belongs to.

Returns:

  • (Hash<String,String>)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#metric_data_queriesArray<Types::MetricDataQuery>

If this SLO monitors a CloudWatch metric or the result of a CloudWatch metric math expression, use this structure to specify that metric or expression.

Returns:



3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

The name of the CloudWatch metric to use for the SLO, when using a custom metric rather than Application Signals standard metrics.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#metric_sourceTypes::MetricSource

Identifies the metric source for SLOs on resources other than Application Signals services.

Returns:



3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#metric_typeString

If the SLO is to monitor either the ‘LATENCY` or `AVAILABILITY` metric that Application Signals collects, use this field to specify which of those metrics is used.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#operation_nameString

If the SLO is to monitor a specific operation of the service, use this field to specify the name of that operation.

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#period_secondsInteger

The number of seconds to use as the period for SLO evaluation. Your application’s performance is compared to the SLI during each period. For each period, the application is determined to have either achieved or not achieved the necessary performance.

Returns:

  • (Integer)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end

#statisticString

The statistic to use for comparison to the threshold. It can be any CloudWatch statistic or extended statistic. For more information about statistics, see [CloudWatch statistics definitions].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Statistics-definitions.html

Returns:

  • (String)


3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
# File 'lib/aws-sdk-applicationsignals/types.rb', line 3180

class ServiceLevelIndicatorMetricConfig < Struct.new(
  :key_attributes,
  :operation_name,
  :metric_type,
  :metric_name,
  :statistic,
  :period_seconds,
  :metric_source,
  :metric_data_queries,
  :dependency_config)
  SENSITIVE = []
  include Aws::Structure
end