Class: Aws::ApplicationSignals::Types::UnprocessedStatusEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ApplicationSignals::Types::UnprocessedStatusEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-applicationsignals/types.rb
Overview
A status event that could not be processed by the service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed_reason ⇒ String
The reason why this status event could not be processed, such as throttling or validation errors.
-
#instrumentation_type ⇒ String
The type of instrumentation configuration for the unprocessed status event.
-
#location_hash ⇒ String
The stable hash of the instrumentation location for the unprocessed event.
-
#signal_type ⇒ String
The telemetry signal type for the unprocessed status event.
-
#status ⇒ String
The status that failed to be processed.
-
#time ⇒ Time
The timestamp of the status event that failed to be processed.
Instance Attribute Details
#failed_reason ⇒ String
The reason why this status event could not be processed, such as throttling or validation errors.
5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067 class UnprocessedStatusEvent < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :failed_reason) SENSITIVE = [] include Aws::Structure end |
#instrumentation_type ⇒ String
The type of instrumentation configuration for the unprocessed status event.
5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067 class UnprocessedStatusEvent < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :failed_reason) SENSITIVE = [] include Aws::Structure end |
#location_hash ⇒ String
The stable hash of the instrumentation location for the unprocessed event.
5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067 class UnprocessedStatusEvent < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :failed_reason) SENSITIVE = [] include Aws::Structure end |
#signal_type ⇒ String
The telemetry signal type for the unprocessed status event.
5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067 class UnprocessedStatusEvent < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :failed_reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status that failed to be processed.
5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067 class UnprocessedStatusEvent < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :failed_reason) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Time
The timestamp of the status event that failed to be processed.
5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 |
# File 'lib/aws-sdk-applicationsignals/types.rb', line 5067 class UnprocessedStatusEvent < Struct.new( :instrumentation_type, :signal_type, :location_hash, :status, :time, :failed_reason) SENSITIVE = [] include Aws::Structure end |