Class: Aws::ApplicationSignals::Types::UpdateServiceLevelObjectiveInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-applicationsignals/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_investigation_enabledBoolean

Indicates whether DevOps Agent will automatically investigate this SLO when it is breached

Returns:

  • (Boolean)


4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4028

class UpdateServiceLevelObjectiveInput < Struct.new(
  :id,
  :description,
  :sli_config,
  :request_based_sli_config,
  :goal,
  :burn_rate_configurations,
  :auto_investigation_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#burn_rate_configurationsArray<Types::BurnRateConfiguration>

Use this array to create *burn rates* for this SLO. Each burn rate is a metric that indicates how fast the service is consuming the error budget, relative to the attainment goal of the SLO.

Returns:



4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4028

class UpdateServiceLevelObjectiveInput < Struct.new(
  :id,
  :description,
  :sli_config,
  :request_based_sli_config,
  :goal,
  :burn_rate_configurations,
  :auto_investigation_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

An optional description for the SLO.

Returns:

  • (String)


4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4028

class UpdateServiceLevelObjectiveInput < Struct.new(
  :id,
  :description,
  :sli_config,
  :request_based_sli_config,
  :goal,
  :burn_rate_configurations,
  :auto_investigation_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#goalTypes::Goal

A structure that contains the attributes that determine the goal of the SLO. This includes the time period for evaluation and the attainment threshold.

Returns:



4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4028

class UpdateServiceLevelObjectiveInput < Struct.new(
  :id,
  :description,
  :sli_config,
  :request_based_sli_config,
  :goal,
  :burn_rate_configurations,
  :auto_investigation_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The Amazon Resource Name (ARN) or name of the service level objective that you want to update.

Returns:

  • (String)


4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4028

class UpdateServiceLevelObjectiveInput < Struct.new(
  :id,
  :description,
  :sli_config,
  :request_based_sli_config,
  :goal,
  :burn_rate_configurations,
  :auto_investigation_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#request_based_sli_configTypes::RequestBasedServiceLevelIndicatorConfig

If this SLO is a request-based SLO, this structure defines the information about what performance metric this SLO will monitor.

You can’t specify both ‘SliConfig` and `RequestBasedSliConfig` in the same operation.



4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4028

class UpdateServiceLevelObjectiveInput < Struct.new(
  :id,
  :description,
  :sli_config,
  :request_based_sli_config,
  :goal,
  :burn_rate_configurations,
  :auto_investigation_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#sli_configTypes::ServiceLevelIndicatorConfig

If this SLO is a period-based SLO, this structure defines the information about what performance metric this SLO will monitor.



4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
# File 'lib/aws-sdk-applicationsignals/types.rb', line 4028

class UpdateServiceLevelObjectiveInput < Struct.new(
  :id,
  :description,
  :sli_config,
  :request_based_sli_config,
  :goal,
  :burn_rate_configurations,
  :auto_investigation_enabled)
  SENSITIVE = []
  include Aws::Structure
end